@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile: checkduplicates.cpp,v $
                              -------------------
-    cvs         : $Id: checkduplicates.cpp,v 1.12 2005/08/25 15:51:24 aquamaniac Exp $
+    cvs         : $Id: checkduplicates.cpp,v 1.15 2006/03/08 15:38:34 aquamaniac Exp $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -42,7 +42,7 @@ CheckDuplicates::CheckDuplicates(KBanking *kb,
 ,_app(kb)
 ,_aborted(false){
 
-  QObject::connect((QObject*)abortButton, SIGNAL(clicked()),
+  QObject::connect(abortButton, SIGNAL(clicked()),
                    this, SLOT(slotAbortClicked()));
 
   accountsProgress->setTotalSteps(-1);
@@ -287,7 +287,6 @@ bool CheckDuplicates::adjustDates() {
     std::list<RefPointer<Transaction> >::iterator xait;
 
     // reset last transaction date
-    (*it)->setLastTransactionDate(0);
     st=(*it)->getStorage();
     assert(st);
 
@@ -493,7 +492,7 @@ bool CheckDuplicates::adjustDates() {
 
   abortButton->setEnabled(false);
 
-  QMessageBox::information(0,
+  QMessageBox::information(this,
                            tr("Transaction Database Updated"),
                            tr("<qt>"
                               "<p>"
@@ -509,7 +508,7 @@ bool CheckDuplicates::adjustDates() {
                               "<b>QBankManager</b>"
                               "</p>"
                               "</qt>"),
-                           tr("Dismiss"), 0, 0, 0);
+                           tr("Dismiss"), QString::null);
 
   return true;
 }
@@ -731,7 +730,7 @@ bool CheckDuplicates::gatherInfoFromPurpose() {
 
   abortButton->setEnabled(false);
 
-  QMessageBox::information(0,
+  QMessageBox::information(this,
                            tr("Transaction Database Updated"),
                            tr("<qt>"
                               "<p>"
@@ -747,7 +746,7 @@ bool CheckDuplicates::gatherInfoFromPurpose() {
                               "<b>QBankManager</b>"
                               "</p>"
                               "</qt>"),
-                           tr("Dismiss"), 0, 0, 0);
+                           tr("Dismiss"), QString::null);
 
   return true;
 }
