@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile: editeutransaction.cpp,v $
                              -------------------
-    cvs         : $Id: editeutransaction.cpp,v 1.9 2005/08/08 14:18:35 aquamaniac Exp $
+    cvs         : $Id: editeutransaction.cpp,v 1.14 2005/10/02 14:05:27 cstim Exp $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -33,7 +33,7 @@
 #include <qlabel.h>
 #include <qlayout.h>
 #include <qtimer.h>
-
+#include <qpushbutton.h>
 
 #include <list>
 #include <string>
@@ -72,9 +72,10 @@ EditEuTransaction::EditEuTransaction(KBanking *app,
   std::list<RefPointer<Transfer> >::iterator xit;
   const AB_VALUE *v;
   //QRegExp valueRx("^[0-9]{1,12}.[0-9]{1,2}$");
-  QRegExp bankCodeRx("^[0-9]{1,8}$");
+  QRegExp bankCodeRx(QString("^[0-9]{1,8}$"));
   //QValidator *valueValidator=new QRegExpValidator(valueRx, this);
   QValidator *bankCodeValidator=new QRegExpValidator(bankCodeRx, this);
+  GWEN_TYPE_UINT64 an;
 
   QLayout *lo=layout();
   if (lo) {
@@ -106,13 +107,17 @@ EditEuTransaction::EditEuTransaction(KBanking *app,
   // setup account combo
   found=0;
   i=0;
+  an=App::char2uint64(t.ref().getLocalAccountNumber().c_str());
   localAccountCombo->insertItem(tr("Select Account"), -1);
   for (ait=app->getAppAccounts().begin();
        ait!=app->getAppAccounts().end();
        ait++) {
+    GWEN_TYPE_UINT64 lan;
+
     i++;
     cs="";
 
+    lan=App::char2uint64((*ait)->getAccountNumber().c_str());
     s=QString::fromUtf8((*ait)->getBankName().c_str());
     if (s.isEmpty())
       s=QString::fromUtf8((*ait)->getBankCode().c_str());
@@ -130,6 +135,10 @@ EditEuTransaction::EditEuTransaction(KBanking *app,
         (strcasecmp((*ait)->getAccountNumber().c_str(),
                     t.ref().getLocalAccountNumber().c_str())==0))
       found=i;
+    else if (an && lan && an==lan &&
+             (strcasecmp((*ait)->getBankCode().c_str(),
+                         t.ref().getLocalBankCode().c_str())==0))
+      found=i;
   } // for
   localAccountCombo->setCurrentItem(found);
   if (found)
@@ -203,31 +212,31 @@ EditEuTransaction::EditEuTransaction(KBanking *app,
                                        "</qt>"
                                       ))
                             .arg(cs),
-                            tr("Dismiss"), 0, 0, 0);
+                            tr("Dismiss"), QString::null);
     }
   }
 
   // connect buttons
-  QObject::connect((QObject*)bankCodeButton, SIGNAL(clicked()),
+  QObject::connect(bankCodeButton, SIGNAL(clicked()),
                    this, SLOT(slotBankCode()));
-  QObject::connect((QObject*)payeeButton, SIGNAL(clicked()),
+  QObject::connect(payeeButton, SIGNAL(clicked()),
                    this, SLOT(slotGetPayee()));
-  QObject::connect((QObject*)bankCodeButton, SIGNAL(clicked()),
+  QObject::connect(bankCodeButton, SIGNAL(clicked()),
                    this, SLOT(slotGetBankCode()));
 
-  QObject::connect((QObject*)localAccountCombo, SIGNAL(activated(int)),
+  QObject::connect(localAccountCombo, SIGNAL(activated(int)),
                    this, SLOT(slotAccountChanged(int)));
-  QObject::connect((QObject*)countryCombo, SIGNAL(activated(const QString &)),
+  QObject::connect(countryCombo, SIGNAL(activated(const QString &)),
                    this, SLOT(slotCountryChanged(const QString &)));
 
-  QObject::connect((QObject*)accountRadio, SIGNAL(toggled(bool)),
+  QObject::connect(accountRadio, SIGNAL(toggled(bool)),
                    this, SLOT(slotAccountIdToggled(bool)));
-  QObject::connect((QObject*)ibanRadio, SIGNAL(toggled(bool)),
+  QObject::connect(ibanRadio, SIGNAL(toggled(bool)),
                    this, SLOT(slotIbanToggled(bool)));
 
-  QObject::connect((QObject*)remoteBankCodeEdit, SIGNAL(lostFocus()),
+  QObject::connect(remoteBankCodeEdit, SIGNAL(lostFocus()),
                    this, SLOT(slotBankCodeLostFocus()));
-  QObject::connect((QObject*)remoteIbanEdit,
+  QObject::connect(remoteIbanEdit,
                    SIGNAL(textChanged(const QString &)),
                    this, SLOT(slotIbanChanged(const QString &)));
 
@@ -261,7 +270,7 @@ void EditEuTransaction::accept(){
   Account *a;
   AB_VALUE *value;
   QCString utfData;
-  QRegExp valueRx("^[0-9]{1,12}.[0-9]{1,2}$");
+  QRegExp valueRx(QString("^[0-9]{1,12}.[0-9]{1,2}$"));
   QRegExpValidator qv(valueRx, this);
 
   pos=0;
@@ -293,7 +302,7 @@ void EditEuTransaction::accept(){
                              "</p>"
                              "</qt>"
                             ),
-                          tr("Dismiss"), 0, 0, 0);
+                          tr("Dismiss"), QString::null);
     return;
   }
 
@@ -306,7 +315,7 @@ void EditEuTransaction::accept(){
                              "</p>"
                              "</qt>"
                             ),
-                          tr("Dismiss"), 0, 0, 0);
+                          tr("Dismiss"), QString::null);
     return;
   }
 
@@ -319,7 +328,7 @@ void EditEuTransaction::accept(){
                              "</p>"
                              "</qt>"
                             ),
-                          tr("Dismiss"), 0, 0, 0);
+                          tr("Dismiss"), QString::null);
     return;
   }
 
@@ -343,7 +352,7 @@ void EditEuTransaction::accept(){
                              "</p>"
                              "</qt>"
                             ),
-                          tr("Dismiss"), 0, 0, 0);
+                          tr("Dismiss"), QString::null);
     return;
   }
 
@@ -377,14 +386,14 @@ void EditEuTransaction::accept(){
       QMessageBox::critical(this,
                             tr("Field Error"),
                             qs,
-                            tr("Dismiss"), 0, 0, 0);
+                            tr("Dismiss"), QString::null);
       return;
     }
     if (lines<1) {
       QMessageBox::critical(this,
                             tr("Field Error"),
                             tr("Please enter the purpose."),
-                            tr("Dismiss"), 0, 0, 0);
+                            tr("Dismiss"), QString::null);
       return;
     }
   }
@@ -438,7 +447,8 @@ void EditEuTransaction::accept(){
     int lastBlank;
 
     lastBlank=-1;
-    for (i=0; i<qs.length(); i++) {
+    // In qt4 QString::length() will return a signed int
+    for (i=0; i < unsigned(qs.length()); i++) {
       if (qs.at(i)=='\n') {
         // next line
         if (!currLine.isEmpty()) {
@@ -602,7 +612,7 @@ void EditEuTransaction::slotAccountChanged(int i){
                                  "</p>"
                                  "</qt>"
                                 ),
-                              tr("Dismiss"), 0, 0, 0);
+                              tr("Dismiss"), QString::null);
         countryCombo->setCurrentItem(0);
         qs="";
       }
@@ -678,7 +688,7 @@ bool EditEuTransaction::_selectCountry(const QString &qs, bool byLong,
   _maxLenOtherName=27;
 
   currencyCombo->clear();
-  currencyCombo->insertItem("EUR");
+  currencyCombo->insertItem(QString("EUR"));
 
   i=localAccountCombo->currentItem();
   a=0;
@@ -719,14 +729,14 @@ bool EditEuTransaction::_selectCountry(const QString &qs, bool byLong,
             DBG_ERROR(0, "Updating country combo");
             p=AB_Country_GetLocalName(cnt);
             if (p)
-              countryCombo->setCurrentText(p);
+              countryCombo->setCurrentText(QString::fromUtf8(p));
             else {
               DBG_ERROR(0, "No local country name...");
             }
           }
           p=AB_Country_GetCurrencyCode(cnt);
           if (p)
-            _setComboTextNoDup(currencyCombo, p);
+            _setComboTextNoDup(currencyCombo, QString::fromUtf8(p));
 
           ei=AB_JobEuTransfer_FindCountryInfo(j, AB_Country_GetCode(cnt));
         }
@@ -787,7 +797,7 @@ void EditEuTransaction::slotCountryChanged(const QString &qs){
                                      "</qt>"
                                     ))
                           .arg(qs),
-                          tr("Dismiss"), 0, 0, 0);
+                          tr("Dismiss"), QString::null);
     countryCombo->setCurrentItem(0);
   }
 }
@@ -838,7 +848,7 @@ void EditEuTransaction::slotGetPayee(){
                                          "</qt>"
                                         ))
                               .arg(qs),
-                              tr("Dismiss"), 0, 0, 0);
+                              tr("Dismiss"), QString::null);
       }
       countryCombo->setCurrentItem(0);
       return;
