@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile: editsto.cpp,v $
                              -------------------
-    cvs         : $Id: editsto.cpp,v 1.2 2005/08/08 14:18:35 aquamaniac Exp $
+    cvs         : $Id: editsto.cpp,v 1.6 2005/10/02 14:05:27 cstim Exp $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -92,7 +92,7 @@ EditStandingOrder::EditStandingOrder(KBanking *app,
   std::list<std::string>::const_iterator sit;
   const AB_VALUE *v;
   //QRegExp valueRx("^[0-9]{1,12}.[0-9]{1,2}$");
-  QRegExp bankCodeRx("^[0-9]{1,8}$");
+  QRegExp bankCodeRx(QString("^[0-9]{1,8}$"));
   //QValidator *valueValidator=new QRegExpValidator(valueRx, this);
   QValidator *bankCodeValidator=new QRegExpValidator(bankCodeRx, this);
   const GWEN_TIME *ti;
@@ -279,25 +279,25 @@ EditStandingOrder::EditStandingOrder(KBanking *app,
 
 
   // connect buttons
-  QObject::connect((QObject*)bankCodeButton, SIGNAL(clicked()),
+  QObject::connect(bankCodeButton, SIGNAL(clicked()),
                    this, SLOT(slotBankCode()));
-  QObject::connect((QObject*)payeeButton, SIGNAL(clicked()),
+  QObject::connect(payeeButton, SIGNAL(clicked()),
                    this, SLOT(slotGetPayee()));
-  QObject::connect((QObject*)bankCodeButton, SIGNAL(clicked()),
+  QObject::connect(bankCodeButton, SIGNAL(clicked()),
                    this, SLOT(slotGetBankCode()));
 
-  QObject::connect((QObject*)localAccountCombo, SIGNAL(activated(int)),
+  QObject::connect(localAccountCombo, SIGNAL(activated(int)),
                    this, SLOT(slotAccountChanged(int)));
 
-  QObject::connect((QObject*)monthlyRadio, SIGNAL(toggled(bool)),
+  QObject::connect(monthlyRadio, SIGNAL(toggled(bool)),
 		   this, SLOT(slotMonthlyToggled(bool)));
-  QObject::connect((QObject*)weeklyRadio, SIGNAL(toggled(bool)),
+  QObject::connect(weeklyRadio, SIGNAL(toggled(bool)),
 		   this, SLOT(slotWeeklyToggled(bool)));
 
   if (_isCreateMode) {
-    QObject::connect((QObject*)dayMonthCombo, SIGNAL(activated(int)),
+    QObject::connect(dayMonthCombo, SIGNAL(activated(int)),
 		     this, SLOT(slotAdjustStartDate(int)));
-    QObject::connect((QObject*)dayWeekCombo, SIGNAL(activated(int)),
+    QObject::connect(dayWeekCombo, SIGNAL(activated(int)),
 		     this, SLOT(slotAdjustStartDate(int)));
   }
 
@@ -350,7 +350,7 @@ void EditStandingOrder::accept(){
   Account *a;
   AB_VALUE *value;
   QCString utfData;
-  QRegExp valueRx("^[0-9]{1,12}.[0-9]{1,2}$");
+  QRegExp valueRx(QString("^[0-9]{1,12}.[0-9]{1,2}$"));
   QRegExpValidator qv(valueRx, this);
   QDate qd;
   GWEN_TIME *ti=0;
@@ -384,7 +384,7 @@ void EditStandingOrder::accept(){
                              "</p>"
                              "</qt>"
                             ),
-                          _tr("Dismiss"), 0, 0, 0);
+                          _tr("Dismiss"), QString::null);
     return;
   }
 
@@ -397,7 +397,7 @@ void EditStandingOrder::accept(){
                              "</p>"
                              "</qt>"
                             ),
-                          _tr("Dismiss"), 0, 0, 0);
+                          _tr("Dismiss"), QString::null);
     return;
   }
 
@@ -413,7 +413,7 @@ void EditStandingOrder::accept(){
                              "</p>"
                              "</qt>"
                             ),
-                          _tr("Dismiss"), 0, 0, 0);
+                          _tr("Dismiss"), QString::null);
     return;
   }
 
@@ -431,7 +431,7 @@ void EditStandingOrder::accept(){
                                "</p>"
                                "</qt>"
                               ),
-                            _tr("Dismiss"), 0, 0, 0);
+                            _tr("Dismiss"), QString::null);
       return;
     }
   }
@@ -467,14 +467,14 @@ void EditStandingOrder::accept(){
       QMessageBox::critical(this,
                             _tr("Field Error"),
                             qs,
-                            _tr("Dismiss"), 0, 0, 0);
+                            _tr("Dismiss"), QString::null);
       return;
     }
     if (lines<1) {
       QMessageBox::critical(this,
                             _tr("Field Error"),
                             _tr("Please enter the purpose."),
-                            _tr("Dismiss"), 0, 0, 0);
+                            _tr("Dismiss"), QString::null);
       return;
     }
   }
@@ -517,7 +517,7 @@ void EditStandingOrder::accept(){
 				    "</p>"
 				    "</qt>"
 				   ),
-				_tr("Dismiss"), 0, 0, 0);
+				_tr("Dismiss"), QString::null);
 	  AB_Job_free(j);
 	  return;
 	}
@@ -538,7 +538,7 @@ void EditStandingOrder::accept(){
 				    "</p>"
 				    "</qt>"
 				   ),
-				_tr("Dismiss"), 0, 0, 0);
+				_tr("Dismiss"), QString::null);
 	  AB_Job_free(j);
 	  return;
 	}
@@ -562,7 +562,7 @@ void EditStandingOrder::accept(){
 				    "</p>"
 				    "</qt>"
 				   ),
-				_tr("Dismiss"), 0, 0, 0);
+				_tr("Dismiss"), QString::null);
 	  AB_Job_free(j);
 	  return;
 	}
@@ -575,7 +575,7 @@ void EditStandingOrder::accept(){
 				    "</p>"
 				    "</qt>"
 				   ),
-				_tr("Dismiss"), 0, 0, 0);
+				_tr("Dismiss"), QString::null);
 	  AB_Job_free(j);
 	  return;
 	}
@@ -589,7 +589,7 @@ void EditStandingOrder::accept(){
 				      "</p>"
 				      "</qt>"
 				     ),
-				  _tr("Dismiss"), 0, 0, 0);
+				  _tr("Dismiss"), QString::null);
 	    AB_Job_free(j);
 	    return;
 	  }
@@ -648,7 +648,8 @@ void EditStandingOrder::accept(){
     int lastBlank;
 
     lastBlank=-1;
-    for (i=0; i<qs.length(); i++) {
+    // In qt4 QString::length() will return a signed int
+    for (i=0; i < unsigned(qs.length()); i++) {
       if (qs.at(i)=='\n') {
         // next line
         if (!currLine.isEmpty()) {
@@ -691,7 +692,7 @@ void EditStandingOrder::accept(){
 			    _tr("Field Error"),
 			    _tr("Please select all fields for this "
 				"standing order."),
-			    _tr("Dismiss"), 0, 0, 0);
+			    _tr("Dismiss"), QString::null);
       return;
     }
     _transfer.ref().setPeriod(AB_Transaction_PeriodMonthly);
@@ -711,7 +712,7 @@ void EditStandingOrder::accept(){
 			      _tr("Field Error"),
 			      _tr("Please select start date according to "
 				  "standing order settings."),
-			      _tr("Dismiss"), 0, 0, 0);
+			      _tr("Dismiss"), QString::null);
 	return;
       }
     }
@@ -732,7 +733,7 @@ void EditStandingOrder::accept(){
 			      _tr("Field Error"),
 			      _tr("Please select start date according to "
 				  "standing order settings."),
-			      _tr("Dismiss"), 0, 0, 0);
+			      _tr("Dismiss"), QString::null);
 	return;
       }
     }
@@ -748,7 +749,7 @@ void EditStandingOrder::accept(){
 			    _tr("Field Error"),
 			    _tr("Please select all fields for this "
 				"standing order."),
-			    _tr("Dismiss"), 0, 0, 0);
+			    _tr("Dismiss"), QString::null);
       return;
     }
     _transfer.ref().setPeriod(AB_Transaction_PeriodWeekly);
@@ -799,9 +800,9 @@ void EditStandingOrder::slotBankCode(){
   AB_BANKINFO *bi;
 
   bi=QBSelectBank::selectBank(_app,
-                              0,
+                              this,
                               _tr("Select a Bank"),
-                              "de",
+                              QString("de"),
                               remoteBankCodeEdit->text());
   if (bi) {
     const char *s;
@@ -896,7 +897,7 @@ void EditStandingOrder::slotAccountChanged(int i){
 				    "</p>"
 				    "</qt>"
 				   ),
-				_tr("Dismiss"), 0, 0, 0);
+				_tr("Dismiss"), QString::null);
 	}
       }
       else {
@@ -915,7 +916,7 @@ void EditStandingOrder::slotAccountChanged(int i){
 				    "</p>"
 				    "</qt>"
 				   ),
-				_tr("Dismiss"), 0, 0, 0);
+				_tr("Dismiss"), QString::null);
 	}
       }
 
