@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile: edittransaction.cpp,v $
                              -------------------
-    cvs         : $Id: edittransaction.cpp,v 1.27 2005/08/08 14:18:35 aquamaniac Exp $
+    cvs         : $Id: edittransaction.cpp,v 1.33 2005/12/23 02:44:58 aquamaniac Exp $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -35,6 +35,7 @@
 #include <qtimer.h>
 #include <qdatetime.h>
 #include <qdatetimeedit.h>
+#include <qpushbutton.h>
 
 #include <list>
 #include <string>
@@ -77,9 +78,10 @@ EditTransaction::EditTransaction(KBanking *app,
   std::list<RefPointer<Transfer> >::iterator xit;
   const AB_VALUE *v;
   //QRegExp valueRx("^[0-9]{1,12}.[0-9]{1,2}$");
-  QRegExp bankCodeRx("^[0-9]{1,8}$");
+  QRegExp bankCodeRx(QString("^[0-9]{1,8}$"));
   //QValidator *valueValidator=new QRegExpValidator(valueRx, this);
   QValidator *bankCodeValidator=new QRegExpValidator(bankCodeRx, this);
+  GWEN_TYPE_UINT64 an;
 
   QLayout *lo=layout();
   if (lo) {
@@ -131,13 +133,17 @@ EditTransaction::EditTransaction(KBanking *app,
   // setup account combo
   found=0;
   i=0;
+  an=App::char2uint64(t.ref().getLocalAccountNumber().c_str());
   localAccountCombo->insertItem(_tr("Select Account"), -1);
   for (ait=app->getAppAccounts().begin();
        ait!=app->getAppAccounts().end();
        ait++) {
+    GWEN_TYPE_UINT64 lan;
+
     i++;
     cs="";
 
+    lan=App::char2uint64((*ait)->getAccountNumber().c_str());
     s=QString::fromUtf8((*ait)->getBankName().c_str());
     if (s.isEmpty())
       s=QString::fromUtf8((*ait)->getBankCode().c_str());
@@ -155,6 +161,10 @@ EditTransaction::EditTransaction(KBanking *app,
         (strcasecmp((*ait)->getAccountNumber().c_str(),
                     t.ref().getLocalAccountNumber().c_str())==0))
       found=i;
+    else if (an && lan && an==lan &&
+             (strcasecmp((*ait)->getBankCode().c_str(),
+                         t.ref().getLocalBankCode().c_str())==0))
+      found=i;
   } // for
   localAccountCombo->setCurrentItem(found);
   slotAccountChanged(found);
@@ -191,14 +201,14 @@ EditTransaction::EditTransaction(KBanking *app,
 
 
   // connect buttons
-  QObject::connect((QObject*)bankCodeButton, SIGNAL(clicked()),
+  QObject::connect(bankCodeButton, SIGNAL(clicked()),
                    this, SLOT(slotBankCode()));
-  QObject::connect((QObject*)payeeButton, SIGNAL(clicked()),
+  QObject::connect(payeeButton, SIGNAL(clicked()),
                    this, SLOT(slotGetPayee()));
-  QObject::connect((QObject*)bankCodeButton, SIGNAL(clicked()),
+  QObject::connect(bankCodeButton, SIGNAL(clicked()),
                    this, SLOT(slotGetBankCode()));
 
-  QObject::connect((QObject*)localAccountCombo, SIGNAL(activated(int)),
+  QObject::connect(localAccountCombo, SIGNAL(activated(int)),
                    this, SLOT(slotAccountChanged(int)));
 
   QTimer::singleShot(0, this, SLOT(adjustSize()));
@@ -244,8 +254,7 @@ void EditTransaction::accept(){
   int i;
   Account *a;
   AB_VALUE *value;
-  QCString utfData;
-  QRegExp valueRx("^[0-9]{1,12}.[0-9]{1,2}$");
+  QRegExp valueRx(QString("^[0-9]{1,12}.[0-9]{1,2}$"));
   QRegExpValidator qv(valueRx, this);
   GWEN_TIME *ti;
 
@@ -278,7 +287,7 @@ void EditTransaction::accept(){
                              "</p>"
                              "</qt>"
                             ),
-                          _tr("Dismiss"), 0, 0, 0);
+                          _tr("Dismiss"), QString::null);
     return;
   }
 
@@ -291,7 +300,7 @@ void EditTransaction::accept(){
                              "</p>"
                              "</qt>"
                             ),
-                          _tr("Dismiss"), 0, 0, 0);
+                          _tr("Dismiss"), QString::null);
     return;
   }
 
@@ -307,7 +316,7 @@ void EditTransaction::accept(){
                              "</p>"
                              "</qt>"
                             ),
-                          _tr("Dismiss"), 0, 0, 0);
+                          _tr("Dismiss"), QString::null);
     return;
   }
 
@@ -325,7 +334,7 @@ void EditTransaction::accept(){
                                "</p>"
                                "</qt>"
                               ),
-                            _tr("Dismiss"), 0, 0, 0);
+                            _tr("Dismiss"), QString::null);
       return;
     }
   }
@@ -361,14 +370,14 @@ void EditTransaction::accept(){
       QMessageBox::critical(this,
                             _tr("Field Error"),
                             qs,
-                            _tr("Dismiss"), 0, 0, 0);
+                            _tr("Dismiss"), QString::null);
       return;
     }
     if (lines<1) {
       QMessageBox::critical(this,
                             _tr("Field Error"),
                             _tr("Please enter the purpose."),
-                            _tr("Dismiss"), 0, 0, 0);
+                            _tr("Dismiss"), QString::null);
       return;
     }
   }
@@ -378,7 +387,7 @@ void EditTransaction::accept(){
       QMessageBox::critical(this,
 			    _tr("Field Error"),
                             _tr("Please enter the execution date."),
-                            _tr("Dismiss"), 0, 0, 0);
+                            _tr("Dismiss"), QString::null);
       return;
     }
     else {
@@ -396,7 +405,7 @@ void EditTransaction::accept(){
 				  "</p>"
 				  "</qt>"
 				 ),
-			      _tr("Dismiss"), 0, 0, 0);
+			      _tr("Dismiss"), QString::null);
 	return;
       }
       else if (dt<_minDelay) {
@@ -408,7 +417,7 @@ void EditTransaction::accept(){
 				  "</p>"
 				  "</qt>"
 				 ),
-			      _tr("Dismiss"), 0, 0, 0);
+			      _tr("Dismiss"), QString::null);
 	return;
       }
       if (_maxDelay) {
@@ -421,7 +430,7 @@ void EditTransaction::accept(){
 				    "</p>"
 				    "</qt>"
 				   ),
-				_tr("Dismiss"), 0, 0, 0);
+				_tr("Dismiss"), QString::null);
 	  return;
 	}
       }
@@ -489,7 +498,8 @@ void EditTransaction::accept(){
     int lastBlank;
 
     lastBlank=-1;
-    for (i=0; i<qs.length(); i++) {
+    // In qt4 QString::length() will return a signed int
+    for (i=0; i < unsigned(qs.length()); i++) {
       if (qs.at(i)=='\n') {
         // next line
         if (!currLine.isEmpty()) {
@@ -550,14 +560,15 @@ void EditTransaction::reject(){
 void EditTransaction::slotBankCode(){
   AB_BANKINFO *bi;
 
-  bi=QBSelectBank::selectBank(_app,
-                              0,
-                              tr("Select a Bank"),
-                              "de",
-                              remoteBankCodeEdit->text());
+  bi=_app->selectBank(this,
+                      tr("Select a Bank"),
+                      QString("de"),
+                      remoteBankCodeEdit->text());
   if (bi) {
     const char *s;
 
+    DBG_ERROR(0, "Got a bankInfo");
+
     s=AB_BankInfo_GetBankId(bi);
     if (s)
       remoteBankCodeEdit->setText(QString::fromUtf8(s));
@@ -568,6 +579,7 @@ void EditTransaction::slotBankCode(){
     if (s)
       remoteBankLocationEdit->setText(QString::fromUtf8(s));
     AB_BankInfo_free(bi);
+    DBG_ERROR(0, "Got a bankInfo, done");
   }
 }
 
@@ -616,7 +628,7 @@ void EditTransaction::slotAccountChanged(int i){
                                      "</p>"
                                      "</qt>"
                                     ),
-                                  _tr("Dismiss"), 0, 0, 0);
+                                  _tr("Dismiss"), QString::null);
           }
         }
         else {
@@ -634,7 +646,7 @@ void EditTransaction::slotAccountChanged(int i){
                                      "</p>"
                                      "</qt>"
                                     ),
-                                  _tr("Dismiss"), 0, 0, 0);
+                                  _tr("Dismiss"), QString::null);
           }
         }
       }
@@ -654,7 +666,7 @@ void EditTransaction::slotAccountChanged(int i){
                                      "</p>"
                                      "</qt>"
                                     ),
-                                  _tr("Dismiss"), 0, 0, 0);
+                                  _tr("Dismiss"), QString::null);
           }
         }
         else {
@@ -672,7 +684,7 @@ void EditTransaction::slotAccountChanged(int i){
                                      "</p>"
                                      "</qt>"
                                     ),
-                                  _tr("Dismiss"), 0, 0, 0);
+                                  _tr("Dismiss"), QString::null);
           }
         }
       }
