@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile: exportedit.cpp,v $
                              -------------------
-    cvs         : $Id: exportedit.cpp,v 1.6 2005/08/31 05:24:20 aquamaniac Exp $
+    cvs         : $Id: exportedit.cpp,v 1.11 2006/03/08 15:38:34 aquamaniac Exp $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -54,7 +54,6 @@ ExportEdit::ExportEdit(KBanking *app,
                        WFlags fl)
 :ExportEditUI(parent, name, modal, fl)
 ,_app(app)
-,_ruleName(0)
 ,_dbRules(0)
 ,_dbRule(0)
 ,_dbFilter(0)
@@ -68,23 +67,23 @@ ExportEdit::ExportEdit(KBanking *app,
 
   _dbRules=GWEN_DB_Group_dup(_app->getExportRules());
 
-  QObject::connect((QObject*)newButton, SIGNAL(clicked()),
+  QObject::connect(newButton, SIGNAL(clicked()),
                    this, SLOT(slotNewClicked()));
-  QObject::connect((QObject*)deleteButton, SIGNAL(clicked()),
+  QObject::connect(deleteButton, SIGNAL(clicked()),
                    this, SLOT(slotDeleteClicked()));
-  QObject::connect((QObject*)saveButton, SIGNAL(clicked()),
+  QObject::connect(saveButton, SIGNAL(clicked()),
                    this, SLOT(slotSaveClicked()));
-  QObject::connect((QObject*)rulesCombo, SIGNAL(activated(int)),
+  QObject::connect(rulesCombo, SIGNAL(activated(int)),
                    this, SLOT(slotRuleActivated(int)));
-  QObject::connect((QObject*)transactionsButton, SIGNAL(clicked()),
+  QObject::connect(transactionsButton, SIGNAL(clicked()),
                    this, SLOT(slotTransactionsClicked()));
-  QObject::connect((QObject*)exporterButton, SIGNAL(clicked()),
+  QObject::connect(exporterButton, SIGNAL(clicked()),
                    this, SLOT(slotExporterClicked()));
-  QObject::connect((QObject*)profileButton, SIGNAL(clicked()),
+  QObject::connect(profileButton, SIGNAL(clicked()),
                    this, SLOT(slotProfileClicked()));
-  QObject::connect((QObject*)fileButton, SIGNAL(clicked()),
+  QObject::connect(fileButton, SIGNAL(clicked()),
                    this, SLOT(slotFileClicked()));
-  QObject::connect((QObject*)fileEdit, SIGNAL(textChanged(const QString&)),
+  QObject::connect(fileEdit, SIGNAL(textChanged(const QString&)),
 		   this, SLOT(slotFileNameChanged(const QString &)));
 
   /* fill rule select combo */
@@ -112,7 +111,7 @@ ExportEdit::ExportEdit(KBanking *app,
     assert(_dbRule);
     GWEN_DB_SetCharValue(_dbRule, GWEN_DB_FLAGS_DEFAULT,
                          "name", ruleName);
-    rulesCombo->insertItem(ruleName);
+    rulesCombo->insertItem(QString::fromUtf8(ruleName));
     rulesCombo->setCurrentItem(i);
     slotRuleActivated(i);
   }
@@ -134,7 +133,6 @@ ExportEdit::ExportEdit(KBanking *app,
                        WFlags fl)
 :ExportEditUI(parent, name, modal, fl)
 ,_app(app)
-,_ruleName(0)
 ,_dbRules(0)
 ,_dbRule(0)
 ,_dbFilter(0)
@@ -145,23 +143,23 @@ ExportEdit::ExportEdit(KBanking *app,
 
   _dbRules=GWEN_DB_Group_new("dummy");
 
-  QObject::connect((QObject*)newButton, SIGNAL(clicked()),
+  QObject::connect(newButton, SIGNAL(clicked()),
                    this, SLOT(slotNewClicked()));
-  QObject::connect((QObject*)deleteButton, SIGNAL(clicked()),
+  QObject::connect(deleteButton, SIGNAL(clicked()),
                    this, SLOT(slotDeleteClicked()));
-  QObject::connect((QObject*)saveButton, SIGNAL(clicked()),
+  QObject::connect(saveButton, SIGNAL(clicked()),
                    this, SLOT(slotSaveClicked()));
-  QObject::connect((QObject*)rulesCombo, SIGNAL(activated(int)),
+  QObject::connect(rulesCombo, SIGNAL(activated(int)),
                    this, SLOT(slotRuleActivated(int)));
-  QObject::connect((QObject*)transactionsButton, SIGNAL(clicked()),
+  QObject::connect(transactionsButton, SIGNAL(clicked()),
                    this, SLOT(slotTransactionsClicked()));
-  QObject::connect((QObject*)exporterButton, SIGNAL(clicked()),
+  QObject::connect(exporterButton, SIGNAL(clicked()),
                    this, SLOT(slotExporterClicked()));
-  QObject::connect((QObject*)profileButton, SIGNAL(clicked()),
+  QObject::connect(profileButton, SIGNAL(clicked()),
                    this, SLOT(slotProfileClicked()));
-  QObject::connect((QObject*)fileButton, SIGNAL(clicked()),
+  QObject::connect(fileButton, SIGNAL(clicked()),
                    this, SLOT(slotFileClicked()));
-  QObject::connect((QObject*)fileEdit, SIGNAL(textChanged(const QString&)),
+  QObject::connect(fileEdit, SIGNAL(textChanged(const QString&)),
 		   this, SLOT(slotFileNameChanged(const QString &)));
 
   /* fill rule select combo */
@@ -249,10 +247,11 @@ void ExportEdit::slotNewClicked(){
     if (!dbT)
       break;
 
-    if (QMessageBox::critical(0,
+    int res = QMessageBox::critical(this,
                               tr("Name already exists"),
                               tr("Please choose another name."),
-                              tr("Ok"), tr("Abort"), 0, 0)!=0)
+                              QMessageBox::Ok,QMessageBox::Abort);
+    if (res !=0 && res != QMessageBox::Ok)
       return;
   } // for
 
@@ -308,10 +307,11 @@ void ExportEdit::slotSaveClicked(){
     if (!dbT)
       break;
 
-    if (QMessageBox::critical(0,
+    int res = QMessageBox::critical(this,
                               tr("Name already exists"),
                               tr("Please choose another name."),
-                              tr("Ok"), tr("Abort"), 0, 0)!=0)
+                              QMessageBox::Ok,QMessageBox::Abort);
+    if (res !=0 && res != QMessageBox::Ok)
       return;
   } // for
 
@@ -344,10 +344,11 @@ void ExportEdit::slotSaveClicked(){
 
 void ExportEdit::slotDeleteClicked(){
   if (rulesCombo->count()>1 && _dbRule) {
-    if (QMessageBox::warning(0,
+    int res = QMessageBox::warning(this,
                              tr("Delete Rule"),
                              tr("Do you really want to delete this rule?"),
-                             tr("Yes"), tr("No"), 0, 0)!=0)
+			     QMessageBox::Yes,QMessageBox::No);
+    if (res !=0 && res != QMessageBox::Yes)
       return;
 
     assert(_dbRule);
@@ -364,10 +365,10 @@ void ExportEdit::slotDeleteClicked(){
     GWEN_DB_Dump(_dbRules, stderr, 2);
   }
   else {
-    QMessageBox::critical(0,
+    QMessageBox::critical(this,
                           tr("Error"),
                           tr("You can not delete all rules"),
-                          tr("Ok"), tr("Abort"), 0, 0);
+                          QMessageBox::Ok,QMessageBox::NoButton);
   }
 }
 
@@ -377,10 +378,11 @@ void ExportEdit::slotTransactionsClicked(){
   int rv;
   GWEN_DB_NODE *dbFilters;
   QString qname;
+  std::string name;
   GWEN_DB_NODE *dbT;
 
   dbFilters=GWEN_DB_Group_dup(_app->getTransactionMatcherRules());
-  qname=tr("current");
+  name=_app->tr("current");
 
   dbT=GWEN_DB_GetFirstGroup(dbFilters);
   while(dbT) {
@@ -388,22 +390,23 @@ void ExportEdit::slotTransactionsClicked(){
 
     s=GWEN_DB_GetCharValue(dbT, "name", 0, 0);
     if (s) {
-      if (strcasecmp(qname.latin1(), s)==0) {
+      if (strcasecmp(name.c_str(), s)==0) {
         GWEN_DB_UnlinkGroup(dbT);
-	GWEN_DB_Group_free(dbT);
+        GWEN_DB_Group_free(dbT);
         break;
       }
     }
     dbT=GWEN_DB_GetNextGroup(dbT);
   }
 
+  assert(_dbFilter);
   GWEN_DB_SetCharValue(_dbFilter, GWEN_DB_FLAGS_OVERWRITE_VARS,
-		       "name", qname.utf8());
+                       "name", name.c_str());
   dbT=GWEN_DB_GetGroup(dbFilters, GWEN_PATH_FLAGS_CREATE_GROUP, "rule");
   GWEN_DB_AddGroupChildren(dbT, _dbFilter);
   TransactionFinder tf(_app,
                        dbFilters,
-                       qname.utf8(),
+                       name.c_str(),
                        TRANSFINDER_FLAGS_USE_CATEGORY |
                        TRANSFINDER_FLAGS_EXT_PAYEES,
                        this, "TransactionFinder",
@@ -439,7 +442,7 @@ void ExportEdit::slotExporterClicked(){
 
   tmpImporterList=AB_Banking_GetImExporterDescrs(_app->getCInterface());
   if (!tmpImporterList) {
-    QMessageBox::critical(0,
+    QMessageBox::critical(this,
 			  tr("No Exporters"),
 			  tr("<qt>"
 			     "<p>"
@@ -447,7 +450,7 @@ void ExportEdit::slotExporterClicked(){
 			     "</p>"
 			     "</qt>"
 			    ),
-			  tr("Dismiss"), 0, 0, 0);
+			  tr("Dismiss"), QString::null);
     return;
   }
 
@@ -475,7 +478,7 @@ void ExportEdit::slotExporterClicked(){
 
   if (!count) {
     GWEN_PluginDescription_List2_free(importerList);
-    QMessageBox::critical(0,
+    QMessageBox::critical(this,
 			  tr("No Exporters"),
 			  tr("<qt>"
 			     "<p>"
@@ -483,7 +486,7 @@ void ExportEdit::slotExporterClicked(){
 			     "</p>"
 			     "</qt>"
 			    ),
-			  tr("Dismiss"), 0, 0, 0);
+			  tr("Dismiss"), QString::null);
     return;
   }
 
@@ -498,7 +501,7 @@ void ExportEdit::slotExporterClicked(){
     s=GWEN_PluginDescription_GetName(pd);
     assert(s);
     exporterLabel->setText(QString::fromUtf8(s));
-    profileLabel->setText("");
+    profileLabel->setText(QString::null);
   }
   GWEN_PluginDescription_List2_freeAll(importerList);
   _validate();
@@ -510,7 +513,7 @@ void ExportEdit::slotProfileClicked(){
   GWEN_DB_NODE *profiles;
 
   if (exporterLabel->text().isEmpty()) {
-    QMessageBox::critical(0,
+    QMessageBox::critical(this,
 			  tr("No Exporter"),
 			  tr("<qt>"
 			     "<p>"
@@ -518,7 +521,7 @@ void ExportEdit::slotProfileClicked(){
 			     "</p>"
 			     "</qt>"
 			    ),
-			  tr("Dismiss"), 0, 0, 0);
+			  tr("Dismiss"), QString::null);
     return;
   }
   profiles=AB_Banking_GetImExporterProfiles(_app->getCInterface(),
@@ -550,7 +553,7 @@ void ExportEdit::slotProfileClicked(){
       dbT=dbNext;
     } // while */
     if (count) {
-      SelectProfile w(_app, "Select Exporter Profile",
+      SelectProfile w(_app, tr("Select Exporter Profile"),
 		      profiles,
 		      profileLabel->text().utf8(),
 		      this);
@@ -572,7 +575,7 @@ void ExportEdit::slotProfileClicked(){
     GWEN_DB_Group_free(profiles);
   }
 
-  QMessageBox::critical(0,
+  QMessageBox::critical(this,
                         tr("No Profiles"),
                         tr("<qt>"
                            "<p>"
@@ -584,7 +587,7 @@ void ExportEdit::slotProfileClicked(){
                            "Please select another one or abort."
                            "</qt>"
                           ),
-                        tr("Dismiss"), 0, 0, 0);
+                        tr("Dismiss"), QString::null);
 }
 
 
@@ -668,7 +671,7 @@ bool ExportEdit::_fromDb(GWEN_DB_NODE *db){
   else {
     GWEN_DB_Group_free(_dbProfile);
     _dbProfile=GWEN_DB_Group_new("profile");
-    profileLabel->setText("");
+    profileLabel->setText(QString::null);
   }
 
   transactionsCheck->setChecked(GWEN_DB_GetIntValue(db,
