@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile: transfinder.cpp,v $
                              -------------------
-    cvs         : $Id: transfinder.cpp,v 1.15 2005/08/31 05:24:20 aquamaniac Exp $
+    cvs         : $Id: transfinder.cpp,v 1.23 2006/01/27 08:33:20 aquamaniac Exp $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -66,9 +66,7 @@ TransactionFinder::TransactionFinder(KBanking *kb,
 ,_modifying(false)
 ,_currentCategoryItem(0)
 ,_flags(flags){
-  GWEN_DB_NODE *dbT;
-  int i;
-  int idx;
+  _helpContext="TransactionFinder";
 
   _dbRules=GWEN_DB_Group_dup(dbRules);
 
@@ -94,50 +92,50 @@ TransactionFinder::TransactionFinder(KBanking *kb,
   else
     criteriaTab->removePage(payeeTab2);
 
-  QObject::connect((QObject*)rulesCombo, SIGNAL(activated(int)),
+  QObject::connect(rulesCombo, SIGNAL(activated(int)),
                    this, SLOT(slotRuleActivated(int)));
-  QObject::connect((QObject*)allAccountsCheck, SIGNAL(toggled(bool)),
+  QObject::connect(allAccountsCheck, SIGNAL(toggled(bool)),
                    this, SLOT(slotAllAccountCheckToggled(bool)));
-  QObject::connect((QObject*)rangeCombo, SIGNAL(activated(int)),
+  QObject::connect(rangeCombo, SIGNAL(activated(int)),
                    this, SLOT(slotDateRangeActivated(int)));
 
-  QObject::connect((QObject*)anyAmountRadio, SIGNAL(toggled(bool)),
+  QObject::connect(anyAmountRadio, SIGNAL(toggled(bool)),
                    this, SLOT(slotAnyAmountRadioToggled(bool)));
-  QObject::connect((QObject*)thisAmountRadio, SIGNAL(toggled(bool)),
+  QObject::connect(thisAmountRadio, SIGNAL(toggled(bool)),
                    this, SLOT(slotThisAmountRadioToggled(bool)));
-  QObject::connect((QObject*)rangeAmountRadio, SIGNAL(toggled(bool)),
+  QObject::connect(rangeAmountRadio, SIGNAL(toggled(bool)),
                    this, SLOT(slotRangeAmountRadioToggled(bool)));
-  QObject::connect((QObject*)lessAmountRadio, SIGNAL(toggled(bool)),
+  QObject::connect(lessAmountRadio, SIGNAL(toggled(bool)),
                    this, SLOT(slotLessAmountRadioToggled(bool)));
-  QObject::connect((QObject*)moreAmountRadio, SIGNAL(toggled(bool)),
+  QObject::connect(moreAmountRadio, SIGNAL(toggled(bool)),
                    this, SLOT(slotMoreAmountRadioToggled(bool)));
 
-  QObject::connect((QObject*)payeeListView, SIGNAL(selectionChanged()),
+  QObject::connect(payeeListView, SIGNAL(selectionChanged()),
                    this, SLOT(slotPayeeSelectionChanged()));
-  QObject::connect((QObject*)allPayeesCheck, SIGNAL(toggled(bool)),
+  QObject::connect(allPayeesCheck, SIGNAL(toggled(bool)),
                    this, SLOT(slotAllPayeeCheckToggled(bool)));
 
-  QObject::connect((QObject*)allCategoriesCheck, SIGNAL(toggled(bool)),
+  QObject::connect(allCategoriesCheck, SIGNAL(toggled(bool)),
                    this, SLOT(slotAllCategoryCheckToggled(bool)));
 
-  QObject::connect((QObject*)refreshButton, SIGNAL(clicked()),
+  QObject::connect(refreshButton, SIGNAL(clicked()),
                    this, SLOT(slotRefreshClicked()));
-  QObject::connect((QObject*)resetButton, SIGNAL(clicked()),
+  QObject::connect(resetButton, SIGNAL(clicked()),
                    this, SLOT(slotResetClicked()));
-  QObject::connect((QObject*)closeButton, SIGNAL(clicked()),
+  QObject::connect(closeButton, SIGNAL(clicked()),
                    this, SLOT(accept()));
-  QObject::connect((QObject*)abortButton, SIGNAL(clicked()),
+  QObject::connect(abortButton, SIGNAL(clicked()),
                    this, SLOT(reject()));
-  QObject::connect((QObject*)newRuleButton, SIGNAL(clicked()),
+  QObject::connect(newRuleButton, SIGNAL(clicked()),
                    this, SLOT(slotNewRuleClicked()));
-  QObject::connect((QObject*)deleteRuleButton, SIGNAL(clicked()),
+  QObject::connect(deleteRuleButton, SIGNAL(clicked()),
                    this, SLOT(slotDeleteRuleClicked()));
-  QObject::connect((QObject*)saveRuleButton, SIGNAL(clicked()),
+  QObject::connect(saveRuleButton, SIGNAL(clicked()),
                    this, SLOT(slotSaveRuleClicked()));
-  QObject::connect((QObject*)accountListView, SIGNAL(selectionChanged()),
+  QObject::connect(accountListView, SIGNAL(selectionChanged()),
                    this, SLOT(slotAccountSelectionChanged()));
 
-  QObject::connect((QObject*)categoryListView,
+  QObject::connect(categoryListView,
                    SIGNAL(contextMenuRequested(QListViewItem *,
                                                const QPoint &,
                                                int)),
@@ -145,49 +143,14 @@ TransactionFinder::TransactionFinder(KBanking *kb,
                    SLOT(slotCategoryContextMenuRequested(QListViewItem *,
                                                          const QPoint &,
                                                          int)));
-  QObject::connect((QObject*)categoryListView, SIGNAL(selectionChanged()),
+  QObject::connect(categoryListView, SIGNAL(selectionChanged()),
                    this, SLOT(slotCategorySelectionChanged()));
 
-  QObject::connect((QObject*)helpButton, SIGNAL(clicked()),
+  QObject::connect(helpButton, SIGNAL(clicked()),
 		   this, SLOT(slotHelp()));
 
   textMatcher->setLabel(tr("Text"));
   payeeMatcher->setLabel(tr("Payee"));
-
-  /* fill rule select combo */
-  dbT=GWEN_DB_FindFirstGroup(_dbRules, "rule");
-  i=0;
-  idx=-1;
-  while(dbT) {
-    const char *s;
-
-    s=GWEN_DB_GetCharValue(dbT, "name", 0, 0);
-    if (s) {
-      if (strcasecmp(s, ruleName)==0 && idx==-1) {
-        _dbRule=dbT;
-        idx=i;
-      }
-    }
-    _addRule(dbT);
-    i++;
-    dbT=GWEN_DB_FindNextGroup(dbT, "rule");
-  }
-  if (idx==-1) {
-    DBG_NOTICE(0, "Rule %s does not exist", ruleName);
-    _dbRule=GWEN_DB_GetGroup(_dbRules, GWEN_PATH_FLAGS_CREATE_GROUP,
-                             "rule");
-    assert(_dbRule);
-    GWEN_DB_SetCharValue(_dbRule, GWEN_DB_FLAGS_DEFAULT,
-                         "name", ruleName);
-    rulesCombo->insertItem(ruleName);
-    rulesCombo->setCurrentItem(i);
-    slotRuleActivated(i);
-  }
-  else {
-    rulesCombo->setCurrentItem(idx);
-    slotRuleActivated(idx);
-  }
-
 }
 
 
@@ -200,8 +163,9 @@ TransactionFinder::~TransactionFinder(){
 
 bool TransactionFinder::init(){
   GWEN_DB_NODE *db;
+  GWEN_DB_NODE *dbT;
   std::string s;
-  int i, j;
+  int i, j, idx;
 
   categoryListView->beginModify();
   db=_app->getAppData();
@@ -337,11 +301,46 @@ bool TransactionFinder::init(){
     } /* if settings */
   }
 
+  /* fill with data from application */
   accountListView->addAccounts(_app->getAppAccounts());
   payeeListView->addPayees(_app->getPayees());
   categoryListView->addCategories(_app->getCategories());
   categoryListView->expandAll();
-  slotRuleActivated(rulesCombo->currentItem());
+
+  /* fill rule select combo */
+  dbT=GWEN_DB_FindFirstGroup(_dbRules, "rule");
+  i=0;
+  idx=-1;
+  while(dbT) {
+    const char *s;
+
+    s=GWEN_DB_GetCharValue(dbT, "name", 0, 0);
+    if (s) {
+      if (strcasecmp(s, _ruleName)==0 && idx==-1) {
+        _dbRule=dbT;
+        idx=i;
+      }
+    }
+    _addRule(dbT);
+    i++;
+    dbT=GWEN_DB_FindNextGroup(dbT, "rule");
+  }
+  if (idx==-1) {
+    DBG_NOTICE(0, "Rule %s does not exist", _ruleName);
+    _dbRule=GWEN_DB_GetGroup(_dbRules, GWEN_PATH_FLAGS_CREATE_GROUP,
+                             "rule");
+    assert(_dbRule);
+    GWEN_DB_SetCharValue(_dbRule, GWEN_DB_FLAGS_DEFAULT,
+                         "name", _ruleName);
+    rulesCombo->insertItem(QString::fromUtf8(_ruleName));
+    rulesCombo->setCurrentItem(i);
+    slotRuleActivated(i);
+  }
+  else {
+    rulesCombo->setCurrentItem(idx);
+    slotRuleActivated(idx);
+  }
+
   categoryListView->endModify();
 
   return true;
@@ -530,9 +529,15 @@ bool TransactionFinder::_fromDb(GWEN_DB_NODE *db){
 
       gr=GWEN_DB_FindFirstGroup(dbSelected, "account");
       while(gr) {
-        accountListView->selectAccounts(GWEN_DB_GetCharValue(gr, "bankId", 0, ""),
-                                 GWEN_DB_GetCharValue(gr, "accountId", 0, ""),
-                                 true);
+        const char *bankId;
+        const char *accountId;
+
+        bankId=GWEN_DB_GetCharValue(gr, "bankId", 0, "*");
+        accountId=GWEN_DB_GetCharValue(gr, "accountId", 0, "*");
+        accountListView
+          ->selectAccountsOnly(bankId,
+                               accountId,
+                               true);
         gr=GWEN_DB_FindNextGroup(gr, "account");
       }
     } /* if dbSelected */
@@ -612,9 +617,9 @@ bool TransactionFinder::_fromDb(GWEN_DB_NODE *db){
   /* payee tab1/tab2 */
   if (_flags & TRANSFINDER_FLAGS_EXT_PAYEES) {
     allPayeesCheck->setChecked(GWEN_DB_GetIntValue(db,
-						   "payees2/allPayees",
-						   0, 1));
-    if (allPayeesCheck->isOn())
+                                                   "payee2/allPayees",
+                                                   0, 1));
+    if (allPayeesCheck->isChecked())
       payeeListView->selectAll(true);
     else {
       dbT=GWEN_DB_GetGroup(db, GWEN_PATH_FLAGS_NAMEMUSTEXIST, "payee2");
@@ -626,7 +631,7 @@ bool TransactionFinder::_fromDb(GWEN_DB_NODE *db){
 	  s=GWEN_DB_GetCharValue(dbT, "payees", i, 0);
 	  if (!s)
 	    break;
-	  payeeListView->selectPayee(s, true);
+          payeeListView->selectPayeeOnly(s, true);
 	}
       }
     }
@@ -710,6 +715,9 @@ bool TransactionFinder::_toDb(GWEN_DB_NODE *db, bool showErrors){
                              "bankId", (*it)->getBankCode().c_str());
         GWEN_DB_SetCharValue(dbt2, GWEN_DB_FLAGS_OVERWRITE_VARS,
                              "accountId", (*it)->getAccountNumber().c_str());
+        DBG_DEBUG(0, "Selected account: %s/%s",
+                  (*it)->getBankCode().c_str(),
+                  (*it)->getAccountNumber().c_str());
       } // for
     } // if there are accounts selected
   }
@@ -757,19 +765,19 @@ bool TransactionFinder::_toDb(GWEN_DB_NODE *db, bool showErrors){
     s=QBanking::QStringToUtf8String(qs);
     if (s.empty()) {
       if (showErrors)
-        QMessageBox::critical(0,
+        QMessageBox::critical(this,
                               tr("Empty amount"),
                               tr("The <i>exact</i> amount field is empty."),
-                              tr("Dismiss"), 0, 0, 0);
+                              tr("Dismiss"), QString::null);
       return false;
     }
     v=AB_Value_fromString(s.c_str());
     if (!v) {
       if (showErrors)
-        QMessageBox::critical(0,
+        QMessageBox::critical(this,
                               tr("Bad amount"),
                               tr("The <i>exact</i> amount field is invalid."),
-                              tr("Dismiss"), 0, 0, 0);
+                              tr("Dismiss"), QString::null);
       return false;
     }
     AB_Value_free(v);
@@ -784,19 +792,19 @@ bool TransactionFinder::_toDb(GWEN_DB_NODE *db, bool showErrors){
     s=QBanking::QStringToUtf8String(qs);
     if (s.empty()) {
       if (showErrors)
-        QMessageBox::critical(0,
+        QMessageBox::critical(this,
                               tr("Empty amount"),
                               tr("The <i>from</i> amount field is empty."),
-                              tr("Dismiss"), 0, 0, 0);
+                              tr("Dismiss"), QString::null);
       return false;
     }
     v=AB_Value_fromString(s.c_str());
     if (!v) {
       if (showErrors)
-        QMessageBox::critical(0,
+        QMessageBox::critical(this,
                               tr("Bad amount"),
                               tr("The <i>from</i> amount field is invalid."),
-                              tr("Dismiss"), 0, 0, 0);
+                              tr("Dismiss"), QString::null);
       return false;
     }
     AB_Value_free(v);
@@ -807,19 +815,19 @@ bool TransactionFinder::_toDb(GWEN_DB_NODE *db, bool showErrors){
     s=QBanking::QStringToUtf8String(qs);
     if (s.empty()) {
       if (showErrors)
-        QMessageBox::critical(0,
+        QMessageBox::critical(this,
                               tr("Empty amount"),
                               tr("The <i>to</i> amount field is empty."),
-                              tr("Dismiss"), 0, 0, 0);
+                              tr("Dismiss"), QString::null);
       return false;
     }
     v=AB_Value_fromString(s.c_str());
     if (!v) {
       if (showErrors)
-        QMessageBox::critical(0,
+        QMessageBox::critical(this,
                               tr("Bad amount"),
                               tr("The <i>to</i> amount field is invalid."),
-                              tr("Dismiss"), 0, 0, 0);
+                              tr("Dismiss"), QString::null);
       return false;
     }
     AB_Value_free(v);
@@ -833,19 +841,19 @@ bool TransactionFinder::_toDb(GWEN_DB_NODE *db, bool showErrors){
     s=QBanking::QStringToUtf8String(qs);
     if (s.empty()) {
       if (showErrors)
-        QMessageBox::critical(0,
+        QMessageBox::critical(this,
                               tr("Empty amount"),
                               tr("The <i>less</i> amount field is empty."),
-                              tr("Dismiss"), 0, 0, 0);
+                              tr("Dismiss"), QString::null);
       return false;
     }
     v=AB_Value_fromString(s.c_str());
     if (!v) {
       if (showErrors)
-        QMessageBox::critical(0,
+        QMessageBox::critical(this,
                               tr("Bad amount"),
                               tr("The <i>less</i> amount field is invalid."),
-                              tr("Dismiss"), 0, 0, 0);
+                              tr("Dismiss"), QString::null);
       return false;
     }
     AB_Value_free(v);
@@ -859,19 +867,19 @@ bool TransactionFinder::_toDb(GWEN_DB_NODE *db, bool showErrors){
     s=QBanking::QStringToUtf8String(qs);
     if (s.empty()) {
       if (showErrors)
-        QMessageBox::critical(0,
+        QMessageBox::critical(this,
                               tr("Empty amount"),
                               tr("The <i>more</i> amount field is empty."),
-                              tr("Dismiss"), 0, 0, 0);
+                              tr("Dismiss"), QString::null);
       return false;
     }
     v=AB_Value_fromString(s.c_str());
     if (!v) {
       if (showErrors)
-        QMessageBox::critical(0,
+        QMessageBox::critical(this,
                               tr("Bad amount"),
                               tr("The <i>more</i> amount field is invalid."),
-                              tr("Dismiss"), 0, 0, 0);
+                              tr("Dismiss"), QString::null);
       return false;
     }
     AB_Value_free(v);
@@ -1092,9 +1100,9 @@ void TransactionFinder::_resetRule(){
   thisAmountRadio->setChecked(true);
   rangeAmountRadio->setChecked(true);
   anyAmountRadio->setChecked(true);
-  thisAmountEdit->setText("");
-  fromAmountEdit->setText("");
-  toAmountEdit->setText("");
+  thisAmountEdit->setText(QString::null);
+  fromAmountEdit->setText(QString::null);
+  toAmountEdit->setText(QString::null);
 
   /* payee tab1/2 */
   if (_flags & TRANSFINDER_FLAGS_EXT_PAYEES) {
@@ -1171,10 +1179,11 @@ void TransactionFinder::slotNewRuleClicked(){
     if (!dbT)
       break;
 
-    if (QMessageBox::critical(0,
+    int res = QMessageBox::critical(this,
                               tr("Name already exists"),
                               tr("Please choose another name."),
-                              tr("Ok"), tr("Abort"), 0, 0)!=0)
+                              QMessageBox::Ok,QMessageBox::Abort);
+    if (res != 0 && res != QMessageBox::Ok)
       return;
   } // for
 
@@ -1257,10 +1266,11 @@ void TransactionFinder::slotSaveRuleClicked(){
     if (!dbT)
       break;
 
-    if (QMessageBox::critical(0,
+    int res = QMessageBox::critical(this,
                               tr("Name already exists"),
                               tr("Please choose another name."),
-                              tr("Ok"), tr("Abort"), 0, 0)!=0)
+                              QMessageBox::Ok,QMessageBox::Abort);
+    if (res != 0 && res != QMessageBox::Ok)
       return;
   } // for
 
@@ -1293,10 +1303,11 @@ void TransactionFinder::slotSaveRuleClicked(){
 
 void TransactionFinder::slotDeleteRuleClicked(){
   if (rulesCombo->count()>1 && _dbRule) {
-    if (QMessageBox::warning(0,
+    int res = QMessageBox::warning(this,
                              tr("Delete Rule"),
                              tr("Do you really want to delete this rule?"),
-                             tr("Yes"), tr("No"), 0, 0)!=0)
+                             QMessageBox::Yes,QMessageBox::No);
+    if (res != 0 && res != QMessageBox::Yes)
       return;
 
     assert(_dbRule);
@@ -1313,10 +1324,10 @@ void TransactionFinder::slotDeleteRuleClicked(){
     //GWEN_DB_Dump(_dbRules, stderr, 2);
   }
   else {
-    QMessageBox::critical(0,
+    QMessageBox::critical(this,
                           tr("Error"),
                           tr("You can not delete all rules"),
-                          tr("Ok"), tr("Abort"), 0, 0);
+                          QMessageBox::Ok,QMessageBox::Abort);
   }
 }
 
@@ -1391,7 +1402,30 @@ void TransactionFinder::slotAccountSelectionChanged() {
 
 
 void TransactionFinder::slotHelp(){
-  _app->invokeHelp("TransFinder");
+  QWidget *w;
+  QString qs;
+
+  w=criteriaTab->currentPage();
+  if (w==textTab)
+    qs="textTab";
+  else if (w==accountTab)
+    qs="accountTab";
+  else if (w==dateTab)
+    qs="dateTab";
+  else if (w==amountTab)
+    qs="amountTab";
+  else if (w==payeeTab)
+    qs="payeeTab";
+  else if (w==payeeTab2)
+    qs="payeeTab2";
+  else if (w==categoryTab)
+    qs="categoryTab";
+  else
+    qs="none";
+  _app->invokeHelp(_helpContext, qs);
+
+
+
 }
 
 
@@ -1470,6 +1504,7 @@ bool TransactionFinder::editRule(KBanking *kb,
     tf.setCaption(title);
   tf.closeButton->setText(tr("Finished"));
   tf.refreshButton->setText(tr("Test"));
+  tf._helpContext="tf_editrule";
 
   tf.init();
   if (tf.exec()==QDialog::Accepted) {
@@ -1539,6 +1574,8 @@ TransactionFinder::selectTransactions(KBanking *kb,
     tf.setCaption(title);
   tf.closeButton->setText(tr("Return Selected"));
   tf.refreshButton->setText(tr("Apply"));
+  tf._helpContext="tf_selecttrans";
+
 
   tf.init();
   if (tf.exec()==QDialog::Accepted) {
@@ -1564,7 +1601,6 @@ void TransactionFinder::slotCategoryContextMenuRequested(QListViewItem *lvi,
                                                          const QPoint &coord,
                                                          int column) {
   QPopupMenu men(categoryListView, "CategoryContextMenu");
-  DBG_ERROR(0, "Right Button Clicked on column %d", column);
 
   _currentCategoryItem=dynamic_cast<CategoryListViewItem*>(lvi);
   assert(_currentCategoryItem);
