@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile: flagstaff.h,v $
                              -------------------
-    cvs         : $Id: flagstaff.h,v 1.9 2005/08/26 16:12:08 aquamaniac Exp $
+    cvs         : $Id: flagstaff.h,v 1.11 2005/09/07 15:38:38 aquamaniac Exp $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -13,10 +13,15 @@
 #ifndef AQHBCI_KDE_FLAGSTAFF_H
 #define AQHBCI_KDE_FLAGSTAFF_H
 
+class FlagStaff;
+
 #include <qobject.h>
 
 #include <qbanking/qbflagstaff.h>
 
+#include "refpointer.h"
+#include "transaction.h"
+
 
 class FlagStaff: public QBFlagStaff {
   Q_OBJECT
