@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile: account.cpp,v $
                              -------------------
-    cvs         : $Id: account.cpp,v 1.24 2005/08/25 15:27:35 aquamaniac Exp $
+    cvs         : $Id: account.cpp,v 1.28 2006/03/10 02:20:52 aquamaniac Exp $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -54,6 +54,13 @@ Account::Account(App *app, const AB_ACCOUNT *a)
 ,_optionExcludeFromGlobalCall(false)
 ,_storage(0)
 ,_lastTransactionDate(0){
+  updateFromBankingAccount(a);
+  _bankingId=AB_Account_GetUniqueId(a);
+}
+
+
+
+void Account::updateFromBankingAccount(const AB_ACCOUNT *a) {
   const char *p;
 
   assert(a);
@@ -75,7 +82,6 @@ Account::Account(App *app, const AB_ACCOUNT *a)
   p=AB_Account_GetOwnerName(a);
   if (p)
     _ownerName=p;
-  _bankingId=AB_Account_GetUniqueId(a);
 }
 
 
@@ -135,10 +141,6 @@ bool Account::fromDb(GWEN_DB_NODE *db) {
   if (dbT)
     _accountStatus=AB_AccountStatus_fromDb(dbT);
   _bankingId=GWEN_DB_GetIntValue(db, "bankingId", 0, 0);
-  dbT=GWEN_DB_GetGroup(db, GWEN_PATH_FLAGS_NAMEMUSTEXIST,
-                       "lastTransactionDate");
-  if (dbT)
-    _lastTransactionDate=GWEN_Time_fromDb(dbT);
 
   /* read transfers */
   dbT=GWEN_DB_GetGroup(db, GWEN_PATH_FLAGS_NAMEMUSTEXIST,
@@ -286,17 +288,6 @@ bool Account::toDb(GWEN_DB_NODE *db) {
     }
   }
 
-  if (_lastTransactionDate) {
-    GWEN_DB_NODE *dbT;
-
-    dbT=GWEN_DB_GetGroup(db, GWEN_DB_FLAGS_DEFAULT, "lastTransactionDate");
-    assert(dbT);
-    if (GWEN_Time_toDb(_lastTransactionDate, dbT)) {
-      DBG_ERROR(0, "Could not store date of last transaction");
-      return false;
-    }
-  }
-
   // save transfers
   dbT=GWEN_DB_GetGroup(db, GWEN_DB_FLAGS_OVERWRITE_GROUPS, "transfers");
   for (itt=_transfers.begin(); itt!=_transfers.end(); itt++) {
@@ -459,6 +450,11 @@ bool Account::_loadTransactions(unsigned int fromYear,
   int rv;
   GWEN_TYPE_UINT32 ymd;
   GWEN_IDLIST *idl;
+  AH_STORAGE *st;
+
+  st=getStorage();
+  if (!st)
+    return false;
 
   DBG_INFO(0, "Loading transactions");
   _transactions.clear();
@@ -466,12 +462,12 @@ bool Account::_loadTransactions(unsigned int fromYear,
   if (!getStorage())
     return false;
 
-  idl=AH_Storage_GetAvailableDays(_storage);
+  idl=AH_Storage_GetAvailableDays(st);
   if (!idl) {
     DBG_ERROR(0, "Error building storage index");
     return false;
   }
-  rv=AH_Storage_GetFirstDay(_storage, idl, &year, &month, &day);
+  rv=AH_Storage_GetFirstDay(st, idl, &year, &month, &day);
   while(!rv) {
     GWEN_TYPE_UINT32 id;
     GWEN_DB_NODE *db;
@@ -481,7 +477,7 @@ bool Account::_loadTransactions(unsigned int fromYear,
               year, month, day);
     cymd=(year<<16)+(month<<8)+day;
     if (cymd>=ymd) {
-      id=AH_Storage_OpenDay(_storage, year, month, day, 1);
+      id=AH_Storage_OpenDay(st, year, month, day, 1);
       if (!id) {
         DBG_ERROR(0, "Error loading day %04d/%02d/%02d",
                   year, month, day);
@@ -489,7 +485,7 @@ bool Account::_loadTransactions(unsigned int fromYear,
         return false;
       }
 
-      db=AH_Storage_GetFirstTransaction(_storage, id);
+      db=AH_Storage_GetFirstTransaction(st, id);
       if (!db) {
         DBG_WARN(0, "No transactions in day %04d/%02d/%02d",
                  year, month, day);
@@ -497,25 +493,26 @@ bool Account::_loadTransactions(unsigned int fromYear,
       while(db) {
         RefPointer<Transaction> t;
 
+        t=new Transaction();
         if (!t.ref().fromDb(db)) {
           DBG_ERROR(0, "Bad format of transaction in day %04d/%02d/%02d",
                     year, month, day);
-          AH_Storage_AbandonDay(_storage, id);
+          AH_Storage_AbandonDay(st, id);
           GWEN_IdList_free(idl);
           return false;
         }
         DBG_VERBOUS(0, "Got a transaction");
         _transactions.push_back(t);
-        db=AH_Storage_GetNextTransaction(_storage, id);
+        db=AH_Storage_GetNextTransaction(st, id);
       }
-      if (AH_Storage_CloseDay(_storage, id)) {
+      if (AH_Storage_CloseDay(st, id)) {
         DBG_ERROR(0, "Error closing day %04d/%02d/%02d",
                   year, month, day);
         GWEN_IdList_free(idl);
         return false;
       }
     }
-    rv=AH_Storage_GetNextDay(_storage, idl, &year, &month, &day);
+    rv=AH_Storage_GetNextDay(st, idl, &year, &month, &day);
     if (rv) {
       DBG_DEBUG(0, "End of day list.");
     }
@@ -535,6 +532,11 @@ bool Account::loadTransactions(GWEN_TIME *fromDate,
   GWEN_TYPE_UINT32 fromYmd;
   GWEN_TYPE_UINT32 toYmd;
   GWEN_IDLIST *idl;
+  AH_STORAGE *st;
+
+  st=getStorage();
+  if (!st)
+    return false;
 
   if (fromDate) {
     if (GWEN_Time_GetBrokenDownUtcDate(fromDate,
@@ -562,12 +564,12 @@ bool Account::loadTransactions(GWEN_TIME *fromDate,
   if (!getStorage())
     return false;
 
-  idl=AH_Storage_GetAvailableDays(_storage);
+  idl=AH_Storage_GetAvailableDays(st);
   if (!idl) {
     DBG_ERROR(0, "Error building storage index");
     return false;
   }
-  rv=AH_Storage_GetFirstDay(_storage, idl, &year, &month, &day);
+  rv=AH_Storage_GetFirstDay(st, idl, &year, &month, &day);
   while(!rv) {
     GWEN_TYPE_UINT32 id;
     GWEN_DB_NODE *db;
@@ -578,7 +580,7 @@ bool Account::loadTransactions(GWEN_TIME *fromDate,
       DBG_DEBUG(0, "Loading day %04d/%02d/%02d",
                 year, month, day);
 
-      id=AH_Storage_OpenDay(_storage, year, month, day, 1);
+      id=AH_Storage_OpenDay(st, year, month, day, 1);
       if (!id) {
         DBG_ERROR(0, "Error loading day %04d/%02d/%02d",
                   year, month, day);
@@ -586,7 +588,7 @@ bool Account::loadTransactions(GWEN_TIME *fromDate,
         return false;
       }
 
-      db=AH_Storage_GetFirstTransaction(_storage, id);
+      db=AH_Storage_GetFirstTransaction(st, id);
       if (!db) {
         DBG_WARN(0, "No transactions in day %04d/%02d/%02d",
                  year, month, day);
@@ -597,22 +599,22 @@ bool Account::loadTransactions(GWEN_TIME *fromDate,
         if (!t.fromDb(db)) {
           DBG_ERROR(0, "Bad format of transaction in day %04d/%02d/%02d",
                     year, month, day);
-          AH_Storage_AbandonDay(_storage, id);
+          AH_Storage_AbandonDay(st, id);
           GWEN_IdList_free(idl);
           return false;
         }
         DBG_DEBUG(0, "Got a transaction");
         tl.push_back(t);
-        db=AH_Storage_GetNextTransaction(_storage, id);
+        db=AH_Storage_GetNextTransaction(st, id);
       }
-      if (AH_Storage_CloseDay(_storage, id)) {
+      if (AH_Storage_CloseDay(st, id)) {
         DBG_ERROR(0, "Error closing day %04d/%02d/%02d",
                   year, month, day);
         GWEN_IdList_free(idl);
         return false;
       }
     }
-    rv=AH_Storage_GetNextDay(_storage, idl, &year, &month, &day);
+    rv=AH_Storage_GetNextDay(st, idl, &year, &month, &day);
     if (rv) {
       DBG_INFO(0, "End of day list.");
     }
@@ -632,6 +634,11 @@ bool Account::loadTransactions(GWEN_TIME *fromDate,
   GWEN_TYPE_UINT32 fromYmd;
   GWEN_TYPE_UINT32 toYmd;
   GWEN_IDLIST *idl;
+  AH_STORAGE *st;
+
+  st=getStorage();
+  if (!st)
+    return false;
 
   if (fromDate) {
     if (GWEN_Time_GetBrokenDownUtcDate(fromDate,
@@ -659,13 +666,13 @@ bool Account::loadTransactions(GWEN_TIME *fromDate,
   if (!getStorage())
     return false;
 
-  idl=AH_Storage_GetAvailableDays(_storage);
+  idl=AH_Storage_GetAvailableDays(st);
   if (!idl) {
     DBG_ERROR(0, "Error building storage index");
     return false;
   }
 
-  rv=AH_Storage_GetFirstDay(_storage, idl, &year, &month, &day);
+  rv=AH_Storage_GetFirstDay(st, idl, &year, &month, &day);
   while(!rv) {
     GWEN_TYPE_UINT32 id;
     GWEN_DB_NODE *db;
@@ -676,7 +683,7 @@ bool Account::loadTransactions(GWEN_TIME *fromDate,
       DBG_DEBUG(0, "Loading day %04d/%02d/%02d",
                 year, month, day);
 
-      id=AH_Storage_OpenDay(_storage, year, month, day, 1);
+      id=AH_Storage_OpenDay(st, year, month, day, 1);
       if (!id) {
         DBG_ERROR(0, "Error loading day %04d/%02d/%02d",
                   year, month, day);
@@ -684,7 +691,7 @@ bool Account::loadTransactions(GWEN_TIME *fromDate,
         return false;
       }
 
-      db=AH_Storage_GetFirstTransaction(_storage, id);
+      db=AH_Storage_GetFirstTransaction(st, id);
       if (!db) {
         DBG_WARN(0, "No transactions in day %04d/%02d/%02d",
                  year, month, day);
@@ -696,22 +703,22 @@ bool Account::loadTransactions(GWEN_TIME *fromDate,
         if (!t.ref().fromDb(db)) {
           DBG_ERROR(0, "Bad format of transaction in day %04d/%02d/%02d",
                     year, month, day);
-          AH_Storage_AbandonDay(_storage, id);
+          AH_Storage_AbandonDay(st, id);
           GWEN_IdList_free(idl);
           return false;
         }
         DBG_DEBUG(0, "Got a transaction");
         tl.push_back(t);
-        db=AH_Storage_GetNextTransaction(_storage, id);
+        db=AH_Storage_GetNextTransaction(st, id);
       }
-      if (AH_Storage_CloseDay(_storage, id)) {
+      if (AH_Storage_CloseDay(st, id)) {
         DBG_ERROR(0, "Error closing day %04d/%02d/%02d",
                   year, month, day);
         GWEN_IdList_free(idl);
         return false;
       }
     }
-    rv=AH_Storage_GetNextDay(_storage, idl, &year, &month, &day);
+    rv=AH_Storage_GetNextDay(st, idl, &year, &month, &day);
     if (rv) {
       DBG_INFO(0, "End of day list.");
     }
@@ -763,23 +770,27 @@ void Account::infoTransactionsChanged(){
 
 
 
-void Account::setLastTransactionDate(const GWEN_TIME *t){
-  if (_lastTransactionDate && t) {
-    if (GWEN_Time_Diff(t, _lastTransactionDate)>0) {
-      GWEN_Time_free(_lastTransactionDate);
-      _lastTransactionDate=GWEN_Time_dup(t);
+const GWEN_TIME *Account::getLastTransactionDate() {
+  GWEN_IDLIST *idl;
+  AH_STORAGE *st;
+
+  GWEN_Time_free(_lastTransactionDate);
+  _lastTransactionDate=0;
+
+  st=getStorage();
+  if (!st)
+    return 0;
+  idl=AH_Storage_GetAvailableDays(st);
+  if (idl) {
+    int year;
+    int month;
+    int day;
+
+    if (!AH_Storage_GetLastDay(st, idl, &year, &month, &day)) {
+      _lastTransactionDate=GWEN_Time_new(year, month-1, day, 12, 0, 0, 1);
+      assert(_lastTransactionDate);
     }
   }
-  else {
-    GWEN_Time_free(_lastTransactionDate);
-    if (t) _lastTransactionDate=GWEN_Time_dup(t);
-    else _lastTransactionDate=0;
-  }
-}
-
-
-
-const GWEN_TIME *Account::getLastTransactionDate() const{
   return _lastTransactionDate;
 }
 
@@ -792,6 +803,11 @@ bool Account::saveTransaction(const Transaction *t) {
   GWEN_TYPE_UINT32 tid;
   GWEN_DB_NODE *dbTransaction;
   GWEN_DB_NODE *dbT;
+  AH_STORAGE *st;
+
+  st=getStorage();
+  if (!st)
+    return false;
 
   dbTransaction=GWEN_DB_Group_new("transaction");
   if (!t->toDb(dbTransaction)) {
@@ -813,7 +829,7 @@ bool Account::saveTransaction(const Transaction *t) {
     return false;
   }
 
-  id=AH_Storage_OpenDay(_storage, year, month+1, day, 0);
+  id=AH_Storage_OpenDay(st, year, month+1, day, 0);
   if (!id) {
     DBG_ERROR(0, "Error loading day %04d/%02d/%02d",
               year, month, day);
@@ -823,30 +839,30 @@ bool Account::saveTransaction(const Transaction *t) {
 
   tid=t->getTransactionId();
   assert(tid);
-  dbT=AH_Storage_GetFirstTransaction(_storage, id);
+  dbT=AH_Storage_GetFirstTransaction(st, id);
   while(dbT) {
     GWEN_TYPE_UINT32 i;
 
     i=GWEN_DB_GetIntValue(dbT, "transactionId", 0, -1);
     if (tid==i)
       break;
-    dbT=AH_Storage_GetNextTransaction(_storage, id);
+    dbT=AH_Storage_GetNextTransaction(st, id);
   }
   if (dbT)
     GWEN_DB_ClearGroup(dbT, 0);
 
   if (!dbT) {
     DBG_INFO(0, "Transaction not found, adding it");
-    if (AH_Storage_AddTransaction(_storage, id, dbTransaction)) {
+    if (AH_Storage_AddTransaction(st, id, dbTransaction)) {
       GWEN_DB_Group_free(dbTransaction);
-      AH_Storage_AbandonDay(_storage, id);
+      AH_Storage_AbandonDay(st, id);
       return false;
     }
   }
   else {
     DBG_INFO(0, "Transaction found, modifying");
     GWEN_DB_AddGroupChildren(dbT, dbTransaction);
-    if (AH_Storage_CloseDay(_storage, id)) {
+    if (AH_Storage_CloseDay(st, id)) {
       DBG_ERROR(0, "Could not close day %04d/%02d/%02d",
                 year, month, day);
       GWEN_DB_Group_free(dbTransaction);
@@ -866,6 +882,11 @@ bool Account::removeTransaction(const Transaction *t) {
   GWEN_TYPE_UINT32 id;
   GWEN_TYPE_UINT32 tid;
   GWEN_DB_NODE *dbT;
+  AH_STORAGE *st;
+
+  st=getStorage();
+  if (!st)
+    return false;
 
   ti=t->getDate();
   if (!ti)
@@ -879,7 +900,7 @@ bool Account::removeTransaction(const Transaction *t) {
     return false;
   }
 
-  id=AH_Storage_OpenDay(_storage, year, month+1, day, 0);
+  id=AH_Storage_OpenDay(st, year, month+1, day, 0);
   if (!id) {
     DBG_ERROR(0, "Error loading day %04d/%02d/%02d",
               year, month, day);
@@ -888,21 +909,21 @@ bool Account::removeTransaction(const Transaction *t) {
 
   tid=t->getTransactionId();
   assert(tid);
-  dbT=AH_Storage_GetFirstTransaction(_storage, id);
+  dbT=AH_Storage_GetFirstTransaction(st, id);
   while(dbT) {
     GWEN_TYPE_UINT32 i;
 
     i=GWEN_DB_GetIntValue(dbT, "transactionId", 0, -1);
     if (tid==i)
       break;
-    dbT=AH_Storage_GetNextTransaction(_storage, id);
+    dbT=AH_Storage_GetNextTransaction(st, id);
   }
 
   if (dbT) {
     DBG_ERROR(0, "Transaction found, removing");
     GWEN_DB_UnlinkGroup(dbT);
     GWEN_DB_Group_free(dbT);
-    if (AH_Storage_CloseDay(_storage, id)) {
+    if (AH_Storage_CloseDay(st, id)) {
       DBG_ERROR(0, "Could not close day %04d/%02d/%02d",
                 year, month, day);
       return false;
@@ -914,6 +935,65 @@ bool Account::removeTransaction(const Transaction *t) {
 
 
 
+bool Account::addTransaction(RefPointer<Transaction> t) {
+  const GWEN_TIME *ti;
+  int year, month, day;
+  GWEN_TYPE_UINT32 id;
+  GWEN_DB_NODE *dbT;
+  AH_STORAGE *st;
+
+  st=getStorage();
+  if (!st)
+    return false;
+
+  ti=t.ref().getDate();
+  if (!ti)
+    ti=t.ref().getValutaDate();
+  if (!ti) {
+    DBG_ERROR(0, "No date in transaction, can not add");
+    return false;
+  }
+  if (GWEN_Time_GetBrokenDownUtcDate(ti, &day, &month, &year)) {
+    DBG_ERROR(0, "Bad date in transaction, can not add it");
+    return false;
+  }
+
+  DBG_ERROR(0, "Saving transaction for day %04d/%02d/%02d (%s/%s)",
+            year, month, day,
+            _bankCode.c_str(), _accountNumber.c_str());
+
+  id=AH_Storage_OpenDay(st, year, month+1, day, 0);
+  if (!id) {
+    DBG_ERROR(0, "Error loading day %04d/%02d/%02d",
+              year, month, day);
+    return false;
+  }
+
+  if (t.ref().getTransactionId()==0)
+    t.ref().setTransactionId(_banking->getNextUniqueId());
+  dbT=GWEN_DB_Group_new("transaction");
+  t.ref().toDb(dbT);
+  if (AH_Storage_AddTransaction(st, id, dbT)) {
+    DBG_ERROR(0, "Could not add transaction");
+    AH_Storage_AbandonDay(st, id);
+    GWEN_DB_Group_free(dbT);
+    return false;
+  }
+  GWEN_DB_Group_free(dbT);
+
+  if (AH_Storage_CloseDay(st, id)) {
+    DBG_ERROR(0, "Could not close day %04d/%02d/%02d",
+              year, month, day);
+    return false;
+  }
+
+  _transactions.clear();
+
+  return true;
+}
+
+
+
 bool Account::saveTransactions() {
   return true;
 }
