@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile: app.cpp,v $
                              -------------------
-    cvs         : $Id: app.cpp,v 1.44 2005/09/01 07:27:38 aquamaniac Exp $
+    cvs         : $Id: app.cpp,v 1.56 2006/03/08 15:38:34 aquamaniac Exp $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -31,7 +31,14 @@
 #include <string.h>
 #include <errno.h>
 #include <ctype.h>
+#ifdef WIN32
+// The regex.h header on win32 is missing this declaration!
+extern "C" {
+#endif
 #include <regex.h>
+#ifdef WIN32
+}
+#endif
 
 #ifdef HAVE_ICONV_H
 # include <iconv.h>
@@ -51,8 +58,14 @@
 App::App(const char *appname, const char *fname)
 :FRONTEND_CLASS(appname, fname)
 , _lastUniqueId(0)
+, _lastSessionId(0)
 , _fuzzyThreshold(APP_FUZZY_THRESHOLD)
-, _sensitiveFuzzyThreshold(APP_FUZZY_SENSITIVE_THRESHOLD){
+, _sensitiveFuzzyThreshold(APP_FUZZY_SENSITIVE_THRESHOLD)
+, _optionAutoAssignPayee(false)
+, _optionAutoAskForPayee(false)
+, _optionAutoAssignCategory(true)
+, _optionAutoAskForCategory(true){
+
 }
 
 
@@ -74,6 +87,8 @@ int App::init() {
   int rv;
   GWEN_TYPE_UINT32 currentVersion;
 
+  _lastSessionId=0;
+
   rv=FRONTEND_CLASS::init();
   if (rv)
     return rv;
@@ -117,7 +132,10 @@ int App::init() {
   _lastCategoryId=GWEN_DB_GetIntValue(db, "lastCategoryId", 0, 0);
 
   _optionAutoAssignPayee=GWEN_DB_GetIntValue(db, "autoAssignPayee", 0, 1);
-  _optionAutoAskForPayee=GWEN_DB_GetIntValue(db, "autoAskForPayee", 0, 1);
+  _optionAutoAskForPayee=GWEN_DB_GetIntValue(db, "autoAskForPayee", 0, 0);
+
+  _optionAutoAssignCategory=GWEN_DB_GetIntValue(db, "autoAssignCategory", 0, 1);
+  _optionAutoAskForCategory=GWEN_DB_GetIntValue(db, "autoAskForCategory", 0, 0);
 
   dbT=GWEN_DB_GetGroup(db, GWEN_PATH_FLAGS_NAMEMUSTEXIST,
                        "accounts");
@@ -316,6 +334,13 @@ int App::fini() {
                       "autoAskForPayee",
                       _optionAutoAskForPayee);
 
+  GWEN_DB_SetIntValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
+                      "autoAssignCategory",
+                      _optionAutoAssignCategory);
+  GWEN_DB_SetIntValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
+                      "autoAskForCategory",
+                      _optionAutoAskForCategory);
+
   dbT=GWEN_DB_GetGroup(db, GWEN_DB_FLAGS_OVERWRITE_GROUPS, "tMatcherRules");
   assert(dbT);
   GWEN_DB_AddGroupChildren(dbT, _xaMatcherRules);
@@ -718,9 +743,28 @@ int App::loadCategories() {
 
 
 
+GWEN_TYPE_UINT64 App::char2uint64(const char *str) {
+  GWEN_TYPE_UINT64 res=0;
+  const char *s;
+
+  s=str;
+  while(*s) {
+    if (*s<'0' || *s>'9')
+      return 0;
+    res*=10;
+    res+=(*s-'0');
+    s++;
+  }
+
+  return res;
+}
+
+
+
 Account *App::findAccount(const char *bankCode,
                           const char *accountNumber) {
   std::list<Account*>::iterator it;
+  GWEN_TYPE_UINT64 an;
 
   if (!bankCode)
     bankCode="";
@@ -735,18 +779,46 @@ Account *App::findAccount(const char *bankCode,
       return *it;
   }
 
+
+  an=char2uint64(accountNumber);
+  if (an) {
+    for (it=_accounts.begin(); it!=_accounts.end(); it++) {
+      GWEN_TYPE_UINT64 lan;
+
+      lan=char2uint64((*it)->getAccountNumber().c_str());
+      if (lan) {
+	if (bankCode) {
+	  if (an==lan &&
+	      strcasecmp((*it)->getBankCode().c_str(),
+			 bankCode)==0)
+            return *it;
+	}
+	else {
+	  if (lan==an)
+            return *it;
+	}
+      }
+    }
+  }
+
   return 0;
 }
 
 
 
+void App::addAccount(Account *a) {
+  _accounts.push_back(a);
+}
+
+
+
 bool App::updateAccountList() {
   std::list<AB_ACCOUNT*> oba;
   std::list<AB_ACCOUNT*>::iterator it;
 
   oba=getAccounts();
   if (oba.size()==0) {
-    DBG_WARN(0, "No accounts");
+    DBG_WARN(0, "No accounts found in aqbanking. Please setup accounts first.");
   }
   for (it=oba.begin(); it!=oba.end(); it++) {
     Account *a;
@@ -886,15 +958,22 @@ GWEN_TYPE_UINT32 App::getNextUniqueId() {
 
 
 
+void App::nextSession() {
+  _lastSessionId=getNextUniqueId();
+}
+
+
+
+GWEN_TYPE_UINT32 App::getLastSessionId() {
+  return _lastSessionId;
+}
+
+
+
 bool App::importContext(AB_IMEXPORTER_CONTEXT *ctx,
                         GWEN_TYPE_UINT32 flags){
   TransactionImporter imp(this, ctx, flags);
 
-  if (!imp.checkTransactions()) {
-    DBG_INFO(0, "Error checking transactions");
-    return false;
-  }
-
   if (!imp.importContext()) {
     DBG_INFO(0, "Error importing transactions");
     return false;
@@ -1010,7 +1089,6 @@ void App::scanJobList(AB_JOB_LIST2 *jl) {
             case AB_Job_StatusUpdated:
             case AB_Job_StatusSent:
             case AB_Job_StatusPending:
-            case AB_Job_StatusDeferred:
               DBG_INFO(0, "Status: Pending");
               t.ref().setStatus(Transfer::StatusPending);
               break;
@@ -1109,6 +1187,19 @@ void App::setExportRules(GWEN_DB_NODE *db){
 
 
 
+std::string App::_stringToLower(const char *s) {
+  std::string result;
+
+  if (s) {
+    while(*s)
+      result+=tolower(*(s++));
+  }
+
+  return result;
+}
+
+
+
 bool App::_textMatches(const std::string &text, GWEN_DB_NODE *db) {
   GWEN_DB_NODE *dbR;
   bool allMustMatch;
@@ -1131,31 +1222,33 @@ bool App::_textMatches(const std::string &text, GWEN_DB_NODE *db) {
       arg=GWEN_DB_GetCharValue(dbR, "argument", 0, 0);
       if (arg) {
         TEXTMATCHER_OPERATION op;
+        std::string val;
 
+        val=_stringToLower(arg);
         op=string2TextMatcherOperation(s);
         switch(op) {
         case TextMatcherOperation_Equals:
-          thisMatches=(strcasecmp(text.c_str(), arg)==0);
+          thisMatches=(strcasecmp(text.c_str(), val.c_str())==0);
           break;
         case TextMatcherOperation_EqualsNot:
-          thisMatches=(strcasecmp(text.c_str(), arg)!=0);
+          thisMatches=(strcasecmp(text.c_str(), val.c_str())!=0);
           break;
         case TextMatcherOperation_Contains:
-          thisMatches=(std::string::npos!=text.find(arg));
+          thisMatches=(std::string::npos!=text.find(val));
           break;
         case TextMatcherOperation_ContainsNot:
-          thisMatches=(std::string::npos==text.find(arg));
+          thisMatches=(std::string::npos==text.find(val));
           break;
         case TextMatcherOperation_MatchesRegExp: {
           regex_t preg;
           int regres;
 
-          regres=regcomp(&preg, arg, REG_EXTENDED);
+          regres=regcomp(&preg, val.c_str(), REG_EXTENDED);
           if (regres) {
             char errBuf[256];
 
             regerror(regres, &preg, errBuf, sizeof(errBuf));
-            DBG_ERROR(0, "regcomp(%s): %s", arg,
+            DBG_ERROR(0, "regcomp(%s): %s", val.c_str(),
                       errBuf);
             regfree(&preg);
             return false;
@@ -1170,7 +1263,7 @@ bool App::_textMatches(const std::string &text, GWEN_DB_NODE *db) {
               char errBuf[256];
 
               regerror(regres, &preg, errBuf, sizeof(errBuf));
-              DBG_ERROR(0, "regexec(%s): %s", arg,
+              DBG_ERROR(0, "regexec(%s): %s", val.c_str(),
                         errBuf);
               regfree(&preg);
               return false;
@@ -1450,6 +1543,7 @@ bool App::_ruleAppliesToTransaction(GWEN_DB_NODE *dbRule,
         purpose+=" ";
       purpose+=*sit;
     }
+    purpose=_stringToLower(purpose.c_str());
     xaMatch=_textMatches(purpose, dbT);
   }
 
@@ -1535,6 +1629,7 @@ bool App::_ruleAppliesToTransaction(GWEN_DB_NODE *dbRule,
         payee+=" ";
       payee+=*sit;
     }
+    payee=_stringToLower(payee.c_str());
     xaMatch=_textMatches(payee, dbT);
   }
 
@@ -2044,6 +2139,30 @@ void App::setOptionAutoAskForPayee(bool b){
 
 
 
+bool App::optionAutoAssignCategory(){
+  return _optionAutoAssignCategory;
+}
+
+
+
+void App::setOptionAutoAssignCategory(bool b){
+  _optionAutoAssignCategory=b;
+}
+
+
+
+bool App::optionAutoAskForCategory(){
+  return _optionAutoAskForCategory;
+}
+
+
+
+void App::setOptionAutoAskForCategory(bool b){
+  _optionAutoAskForCategory=b;
+}
+
+
+
 GWEN_TIME *App::adjustedDate(const GWEN_TIME *pt){
   int hour, minute, sec;
 
