@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile: timport.cpp,v $
                              -------------------
-    cvs         : $Id: timport.cpp,v 1.25 2005/08/25 15:27:35 aquamaniac Exp $
+    cvs         : $Id: timport.cpp,v 1.30 2006/03/08 15:38:34 aquamaniac Exp $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -141,8 +141,14 @@ TransactionImporter::TransactionImporter(App *kb,
 ,_context(ctx)
 ,_flags(flags){
 
+#if 0
+  GWEN_DB_NODE *db;
 
-
+  db=GWEN_DB_Group_new("context");
+  AB_ImExporterContext_toDb(ctx, db);
+  GWEN_DB_WriteFile(db, "/tmp/context.ctx", GWEN_DB_FLAGS_DEFAULT);
+  GWEN_DB_Group_free(db);
+#endif
 
 }
 
@@ -184,6 +190,16 @@ Payee *TransactionImporter::askUserForPayee(RefPointer<Transaction> t,
 
 
 
+Category *TransactionImporter::askUserForCategory(RefPointer<Transaction> t,
+                                                  bool &aborted,
+                                                  bool &askNoMore) {
+  aborted=false;
+  askNoMore=true;
+  return 0;
+}
+
+
+
 TransactionImporter::DupeCheckResult
 TransactionImporter::askUserForDuplicate(Account *a,
                                          RefPointer<Transaction> tnew,
@@ -196,6 +212,14 @@ TransactionImporter::askUserForDuplicate(Account *a,
 
 
 
+bool
+TransactionImporter::presentTransactionsToUser(std::list<RefPointer<Transaction> > &toAdd,
+					       std::list<RefPointer<Transaction> > &toDel) {
+  return true;
+}
+
+
+
 
 bool TransactionImporter::_collapseSplits(AB_TRANSACTION *t,
                                           const std::string &bankCode,
@@ -311,10 +335,8 @@ bool TransactionImporter::sortNewTransactions() {
 
       if (tr) {
         tr->gatherInfoFromPurpose();
-        if (tr->getLocalBankCode().empty())
-	  tr->setLocalBankCode(currentAccount->bankCode());
-	if (tr->getLocalAccountNumber().empty())
-          tr->setLocalAccountNumber(currentAccount->accountNumber());
+	tr->setLocalBankCode(currentAccount->bankCode());
+	tr->setLocalAccountNumber(currentAccount->accountNumber());
 
         ti=tr->getDate();
         if (!ti)
@@ -457,119 +479,13 @@ TransactionImporter::checkForDuplicate(Account *a,
 
 
 
-bool TransactionImporter::_checkDay(Account *a,
-                                    TransactionImporter::DayData *d,
-                                    bool &askNoMore,
-                                    TransactionImporter::DupeCheckResult &lastRv){
+bool
+TransactionImporter::_checkDay(Account *a,
+                               TransactionImporter::DayData *d,
+                               bool &askNoMore,
+                               TransactionImporter::DupeCheckResult &lastRv){
   std::list<RefPointer<Transaction> >::iterator it;
 
-  if (!(_flags & TRANSACTION_IMPORTER_FLAGS_OVERWRITE_DAYS)) {
-    AH_STORAGE *st;
-    GWEN_TYPE_UINT32 hdl;
-  
-    st=a->getStorage();
-    assert(st);
-
-    DBG_DEBUG(0, "Opening day");
-    hdl=AH_Storage_OpenDay(st, d->getYear(), d->getMonth(), d->getDay(), 1);
-    if (hdl) {
-      GWEN_DB_NODE *dbT;
-      std::list<RefPointer<Transaction> > *toAdd;
-      std::list<RefPointer<Transaction> > oldTransactions;
-
-      toAdd=new std::list<RefPointer<Transaction> >();
-
-      // there is data for this day, check it
-      dbT=AH_Storage_GetFirstTransaction(st, hdl);
-      while(dbT) {
-        oldTransactions.push_back(new Transaction(dbT));
-        dbT=AH_Storage_GetNextTransaction(st, hdl);
-      } // while transactions
-
-      // check for duplicates
-      for (it=d->getTransactions()->begin();
-           it!=d->getTransactions()->end();
-           it++) {
-        std::list<RefPointer<Transaction> >::iterator itOld;
-	bool handled;
-
-        DBG_VERBOUS(0, "checking transaction");
-        handled=false;
-
-	// find duplicates
-	for (itOld=oldTransactions.begin();
-	     itOld!=oldTransactions.end();
-	     itOld++) {
-	  bool isEqual;
-
-	  if (_flags & TRANSACTION_IMPORTER_FLAGS_FUZZY) {
-	    DBG_VERBOUS(0, "Fuzzy matching");
-            isEqual=(*it).ref().matchFuzzy((*itOld).ref(),
-                                           _app->getSensitiveFuzzyThreshold());
-	  }
-	  else
-	    isEqual=((*it).ref().getHash()==(*itOld).ref().getHash());
-
-
-	  if (isEqual) {
-	    DupeCheckResult rv;
-
-	    // duplicate candidate
-	    rv=checkForDuplicate(a,
-				 *it, *itOld,
-				 *(d->getTransactions()),
-				 oldTransactions,
-				 askNoMore,
-				 lastRv);
-	    lastRv=rv;
-	    if (rv==DupeCheck_Error) {
-	      DBG_ERROR(0, "User aborted");
-	      AH_Storage_AbandonDay(st, hdl);
-	      delete toAdd;
-	      return false;
-	    }
-	    else if (rv==DupeCheck_AddNew) {
-	      DBG_INFO(0, "Adding duplicate");
-	      toAdd->push_back(*it);
-	    }
-	    else if (rv==DupeCheck_DismissNew) {
-	      // dismiss new transaction
-	      DBG_INFO(0, "Dismissing duplicate");
-	    }
-	    else if (rv==DupeCheck_RemoveOld) {
-	      // dismissing old
-	      DBG_INFO(0, "Removing old transaction");
-	      oldTransactions.erase(itOld);
-	    }
-	    else if (rv==DupeCheck_ReplaceOld) {
-	      // replace old
-	      DBG_INFO(0, "Replacing old transaction");
-	      oldTransactions.erase(itOld);
-	      toAdd->push_back(*it);
-	    }
-
-	    handled=true;
-	    break;
-	  } // for old transactions
-	}
-	if (!handled)
-	  toAdd->push_back(*it);
-      } // for new transactions
-
-      // add old transactions to list
-      for (it=oldTransactions.begin();
-	   it!=oldTransactions.end();
-	   it++)
-	toAdd->push_back(*it);
-      /* replace new data for this day, the new list only contains
-       * transactions which can be safely written
-       */
-      d->replaceTransactions(toAdd);
-      DBG_DEBUG(0, "Closing day");
-      AH_Storage_CloseDay(st, hdl);
-    } // if old data for this day exists
-  } // if not in overwrite mode
-
   // make sure all transactions have a date or valuta date
   for (it=d->getTransactions()->begin();
        it!=d->getTransactions()->end();
@@ -603,14 +519,112 @@ bool TransactionImporter::_checkDay(Account *a,
     } // if no time
   } // for
 
+
+  if (!(_flags & TRANSACTION_IMPORTER_FLAGS_OVERWRITE_DAYS)) {
+    AH_STORAGE *st;
+    GWEN_TYPE_UINT32 hdl;
+  
+    st=a->getStorage();
+    assert(st);
+
+    DBG_DEBUG(0, "Opening day");
+    hdl=AH_Storage_OpenDay(st, d->getYear(), d->getMonth(), d->getDay(), 1);
+    if (hdl) {
+      GWEN_DB_NODE *dbT;
+      std::list<RefPointer<Transaction> > oldTransactions;
+
+      // there is data for this day, check it
+      dbT=AH_Storage_GetFirstTransaction(st, hdl);
+      while(dbT) {
+        oldTransactions.push_back(new Transaction(dbT));
+        dbT=AH_Storage_GetNextTransaction(st, hdl);
+      } // while transactions
+
+      // check for duplicates
+      for (it=d->getTransactions()->begin();
+           it!=d->getTransactions()->end();
+           it++) {
+        std::list<RefPointer<Transaction> >::iterator itOld;
+	bool handled;
+
+        DBG_VERBOUS(0, "checking transaction");
+        handled=false;
+
+	// find duplicates
+	for (itOld=oldTransactions.begin();
+	     itOld!=oldTransactions.end();
+	     itOld++) {
+	  bool isEqual;
+
+	  if (_flags & TRANSACTION_IMPORTER_FLAGS_FUZZY) {
+            isEqual=(*it).ref().matchFuzzy((*itOld).ref(),
+                                           _app->getSensitiveFuzzyThreshold());
+            DBG_DEBUG(0, "Fuzzy matching (%d)", isEqual);
+	  }
+          else {
+            isEqual=((*it).ref().getHash()==(*itOld).ref().getHash());
+            DBG_DEBUG(0, "Hash matching (%d)", isEqual);
+	  }
+
+	  if (isEqual) {
+	    DupeCheckResult rv;
+
+            DBG_DEBUG(0, "Duplicate candidate found");
+
+	    // duplicate candidate
+	    rv=checkForDuplicate(a,
+				 *it, *itOld,
+				 *(d->getTransactions()),
+				 oldTransactions,
+				 askNoMore,
+                                 lastRv);
+            DBG_DEBUG(0, "Result of check: %d", rv);
+	    lastRv=rv;
+	    if (rv==DupeCheck_Error) {
+	      DBG_ERROR(0, "User aborted");
+	      AH_Storage_AbandonDay(st, hdl);
+	      return false;
+	    }
+	    else if (rv==DupeCheck_AddNew) {
+	      DBG_INFO(0, "Adding duplicate");
+	      _toAdd.push_back(*it);
+	    }
+	    else if (rv==DupeCheck_DismissNew) {
+	      // dismiss new transaction
+	      DBG_INFO(0, "Dismissing duplicate");
+	    }
+	    else if (rv==DupeCheck_RemoveOld) {
+	      // dismissing old
+	      DBG_INFO(0, "Removing old transaction");
+              _toDel.push_back(*itOld);
+	    }
+	    else if (rv==DupeCheck_ReplaceOld) {
+	      // replace old
+	      DBG_INFO(0, "Replacing old transaction");
+	      _toDel.push_back(*itOld);
+	      _toAdd.push_back(*it);
+	    }
+
+	    handled=true;
+	    break;
+          } // if is equal
+	}
+	if (!handled)
+	  _toAdd.push_back(*it);
+      } // for new transactions
+
+      DBG_DEBUG(0, "Closing day");
+      AH_Storage_CloseDay(st, hdl);
+    } // if old data for this day exists
+  } // if not in overwrite mode
+
   return true;
 }
 
 
 
-
-
-bool TransactionImporter::checkTransactions(){
+bool
+TransactionImporter::_checkTransactions() {
   std::list<AccountData*>::iterator it;
   DupeCheckResult lastRv=DupeCheck_Error;
   bool askNoMore=false;
@@ -628,9 +642,10 @@ bool TransactionImporter::checkTransactions(){
     for (dit=(*it)->getNewDayList().begin();
          dit!=(*it)->getNewDayList().end();
          dit++) {
-      if (!_checkDay((*it)->account(), *dit, askNoMore, lastRv)) {
-        DBG_INFO(0, "Error checking day");
-        return false;
+      if (!_checkDay((*it)->account(), *dit,
+		     askNoMore, lastRv)) {
+	DBG_INFO(0, "Error checking day");
+	return false;
       }
     } // for days
   } // for accounts
@@ -640,194 +655,297 @@ bool TransactionImporter::checkTransactions(){
 
 
 
-bool TransactionImporter::importTransactions(){
-  std::list<AccountData*>::iterator it;
-  int acnt;
-  bool askUser;
+bool TransactionImporter::_assignCatsAndPayees() {
+  std::list<RefPointer<Transaction> >::iterator it;
+  bool bAskUserForPayee;
+  bool bAskUserForCategory;
+  unsigned int cnt;
 
-  askUser=_app->optionAutoAskForPayee();
+  bAskUserForPayee=_app->optionAutoAskForPayee();
+  bAskUserForCategory=_app->optionAutoAskForCategory();
 
-  acnt=0;
-  for (it=_accountDataList.begin();
-       it!=_accountDataList.end();
-       it++) {
-    std::list<DayData*>::iterator dit;
-    AH_STORAGE *st;
-    int cnt;
+  GWEN_WaitCallback_EnterWithText(GWEN_WAITCALLBACK_ID_FAST,
+				  _app->tr("Assigning categories and payees").c_str(),
+				  _app->tr("transaction(s)").c_str(),
+				  0);
+  GWEN_WaitCallback_SetProgressTotal(_toAdd.size());
+  cnt=0;
+  GWEN_WaitCallback_SetProgressPos(cnt);
 
-    st=(*it)->account()->getStorage();
-    assert(st);
-
-    GWEN_WaitCallback_Enter(TRANSACTION_IMPORTER_CB_ID);
-    GWEN_WaitCallback_SetProgressTotal((*it)->getNewDayList().size());
-    GWEN_WaitCallback_SetProgressPos(0);
-    cnt=0;
-    for (dit=(*it)->getNewDayList().begin();
-         dit!=(*it)->getNewDayList().end();
-         dit++) {
-      GWEN_TYPE_UINT32 hdl;
-      std::list<RefPointer<Transaction> >::iterator xit;
-      GWEN_TIME *ti1;
-
-      DBG_DEBUG(0, "Handling day");
-
-      // TODO: save day
-      hdl=AH_Storage_OpenDay(st,
-                             (*dit)->getYear(),
-                             (*dit)->getMonth(),
-                             (*dit)->getDay(), 0);
-      if (!hdl) {
-	DBG_ERROR(0, "Error opening day");
-        GWEN_WaitCallback_Leave();
-        return false;
-      }
-
-      if (AH_Storage_ClearDay(st, hdl)) {
-        DBG_ERROR(0, "Could not clear day");
-        AH_Storage_AbandonDay(st, hdl);
-        GWEN_WaitCallback_Leave();
-        return false;
-      }
-
-      // get lastTransactionDate
-      // set UTC date, 12 o'clock (in this case: UTC date==local date
-      ti1=GWEN_Time_new((*dit)->getYear(),
-			(*dit)->getMonth()-1,
-			(*dit)->getDay(),
-                        12, 0, 0, 1);
-
-      // add transactions
-      for (xit=(*dit)->getTransactions()->begin();
-           xit!=(*dit)->getTransactions()->end();
-           xit++) {
-	GWEN_DB_NODE *dbT;
-        const GWEN_TIME *ti2;
-
-        DBG_DEBUG(0, "Handling transaction");
-
-        if ((*xit).ref().getPayee().empty()) {
-          Payee *payee=0;
-
-          if (_app->optionAutoAssignPayee()) {
-            payee=_app->findPayeeByTransactionMatch((*xit).ptr());
-            if (!payee) {
-              if (askUser) {
-                bool aborted=false;
-                bool askNoMore=false;
-
-                payee=askUserForPayee((*xit), aborted, askNoMore);
-                if (!payee && aborted) {
-                  DBG_ERROR(0, "User aborted import");
-                  AH_Storage_AbandonDay(st, hdl);
-                  GWEN_Time_free(ti1);
-                  GWEN_WaitCallback_Leave();
-                  return false;
-                }
-                if (askNoMore)
-                  askUser=false;
-              }
-            }
-          }
-          if (payee) {
-            const AB_VALUE *v;
-
-            DBG_DEBUG(0, "Assigning payee %s",
-                      payee->name().c_str());
-            (*xit).ref().setPayee(payee->id());
-            v=(*xit).ref().getValue();
-            if (v) {
-              if (AB_Value_IsNegative(v)) {
-                AB_VALUE *nv;
-
-                nv=AB_Value_dup(v);
-                AB_Value_Negate(nv);
-                payee->addOutValue(nv);
-                AB_Value_free(nv);
-              }
-              else
-                payee->addInValue(v);
-            }
-          }
-        }
-
-        dbT=GWEN_DB_Group_new("transaction");
-        if (!((*xit).ref().toDb(dbT))) {
-          DBG_ERROR(0, "Error storing transaction to DB");
-          AH_Storage_AbandonDay(st, hdl);
-          GWEN_DB_Group_free(dbT);
-	  GWEN_Time_free(ti1);
-	  GWEN_WaitCallback_Leave();
-          return false;
-        }
-
-        if (AH_Storage_AddTransaction(st, hdl, dbT)) {
-          DBG_ERROR(0, "Error storing transaction for day");
-          AH_Storage_AbandonDay(st, hdl);
-          GWEN_DB_Group_free(dbT);
-          GWEN_Time_free(ti1);
-          GWEN_WaitCallback_Leave();
-          return false;
-        }
-
-	ti2=(*it)->account()->getLastTransactionDate();
-	if (ti2) {
-	  if (0) {
-	    GWEN_BUFFER *tbuf;
-
-	    tbuf=GWEN_Buffer_new(0, 32, 0, 1);
-	    GWEN_Time_toString(ti1, "YYYY/MM/DD", tbuf);
-	    DBG_ERROR(0, "Ti1: %s", GWEN_Buffer_GetStart(tbuf));
-	    GWEN_Buffer_Reset(tbuf);
-	    GWEN_Time_toString(ti2, "YYYY/MM/DD", tbuf);
-	    DBG_ERROR(0, "Ti2: %s", GWEN_Buffer_GetStart(tbuf));
-	    GWEN_Buffer_free(tbuf);
-	  }
-	  if (GWEN_Time_Diff(ti2, ti1)<0) {
-	    (*it)->account()->setLastTransactionDate(ti1);
+  /* assign payees and categories */
+  for (it=_toAdd.begin(); it!=_toAdd.end(); it++) {
+    DBG_DEBUG(0, "Handling transaction");
+  
+    if ((*it).ref().getPayee().empty()) {
+      Payee *payee=0;
+  
+      if (_app->optionAutoAssignPayee()) {
+	payee=_app->findPayeeByTransactionMatch((*it).ptr());
+	if (!payee) {
+	  if (bAskUserForPayee) {
+	    bool aborted=false;
+	    bool askNoMore=false;
+  
+	    payee=askUserForPayee((*it), aborted, askNoMore);
+	    if (!payee && aborted) {
+	      DBG_ERROR(0, "User aborted import");
+	      GWEN_WaitCallback_Leave();
+	      return false;
+	    }
+	    if (askNoMore)
+	      bAskUserForPayee=false;
 	  }
 	}
-	else {
-	  (*it)->account()->setLastTransactionDate(ti1);
+	if (payee) {
+	  DBG_DEBUG(0, "Assigning payee %s",
+                    payee->id().c_str());
+	  (*it).ref().setPayee(payee->id());
 	}
-
-	GWEN_DB_Group_free(dbT);
-      } // for transaction
-
-      // close day
-      DBG_DEBUG(0, "Closing day");
-      if (AH_Storage_CloseDay(st, hdl)) {
-        DBG_ERROR(0, "Error storing transaction for day");
-        AH_Storage_AbandonDay(st, hdl);
-	GWEN_Time_free(ti1);
-        GWEN_WaitCallback_Leave();
-        return false;
       }
-      cnt++;
-      GWEN_Time_free(ti1);
-      GWEN_WaitCallbackProgress(cnt);
-    } // for days
-    GWEN_WaitCallback_Leave();
-    _app->appInfoTransactionsChanged((*it)->account());
+    }
 
-    acnt++;
-    GWEN_WaitCallback_SetProgressPos(acnt);
-  } // for accounts
+    if ((*it).ref().getCategory().empty()) {
+      Category *category=0;
+  
+      if (_app->optionAutoAssignCategory()) {
+	category=_app->findCategoryByTransactionMatch((*it).ptr());
+	if (!category) {
+	  if (bAskUserForCategory) {
+	    bool aborted=false;
+	    bool askNoMore=false;
+  
+	    category=askUserForCategory((*it), aborted, askNoMore);
+	    if (!category && aborted) {
+	      DBG_ERROR(0, "User aborted import");
+	      GWEN_WaitCallback_Leave();
+	      return false;
+	    }
+	    if (askNoMore)
+	      bAskUserForCategory=false;
+	  }
+	}
+      }
+      if (category) {
+	DBG_DEBUG(0, "Assigning category %s",
+		  category->getName().c_str());
+	(*it).ref().setCategory(category->getId());
+      }
+    }
+  
+    cnt++;
+    GWEN_WaitCallbackProgress(cnt);
+  } /* for */
+  GWEN_WaitCallback_Leave();
+  return true;
+}
+
+
+
+bool
+TransactionImporter::_adjustPCValues(std::list<RefPointer<Transaction> > &tl,
+				     bool add){
+  std::list<RefPointer<Transaction> >::iterator it;
+  unsigned int cnt;
+
+  GWEN_WaitCallback_EnterWithText(GWEN_WAITCALLBACK_ID_FAST,
+				  _app->tr("Adjusting amounts of categories and payees").c_str(),
+				  _app->tr("transaction(s)").c_str(),
+				  0);
+  GWEN_WaitCallback_SetProgressTotal(tl.size());
+  cnt=0;
+  GWEN_WaitCallback_SetProgressPos(cnt);
+  for (it=tl.begin(); it!=tl.end(); it++) {
+    const AB_VALUE *v;
+
+    v=(*it).ref().getValue();
+    if (v) {
+      std::string spayee;
+      std::string scat;
+
+      spayee=(*it).ref().getPayee();
+      if (!spayee.empty()) {
+	Payee *payee;
+
+	payee=_app->findPayeeById(spayee.c_str());
+	if (payee) {
+	  if (add) {
+	    /* add values */
+	    if (AB_Value_IsNegative(v)) {
+	      AB_VALUE *nv;
+  
+	      nv=AB_Value_dup(v);
+	      AB_Value_Negate(nv);
+	      payee->addOutValue(nv);
+	      AB_Value_free(nv);
+	    }
+	    else
+	      payee->addInValue(v);
+	  }
+	  else {
+	    /* subtract values */
+	    if (AB_Value_IsNegative(v)) {
+	      payee->addOutValue(v);
+	    }
+	    else {
+	      AB_VALUE *nv;
+
+	      nv=AB_Value_dup(v);
+	      AB_Value_Negate(nv);
+	      payee->addInValue(nv);
+	      AB_Value_free(nv);
+	    }
+	  }
+	} // if payee
+      } // if spayee
+
+      scat=(*it).ref().getCategory();
+      if (!scat.empty()) {
+	Category *cat;
+
+	cat=_app->findCategoryById(scat.c_str());
+	if (cat) {
+	  if (add)
+	    cat->addValue(v);
+          else {
+	    /* subtract value */
+	    AB_VALUE *nv;
+
+	    nv=AB_Value_dup(v);
+	    AB_Value_Negate(nv);
+	    cat->addValue(nv);
+	    AB_Value_free(nv);
+	  }
+	}
+      }
+    } // if v
+    cnt++;
+    GWEN_WaitCallbackProgress(cnt);
+  } // for
+  GWEN_WaitCallback_Leave();
 
   return true;
 }
 
 
 
+bool TransactionImporter::importTransactions(){
+  std::list<RefPointer<Transaction> >::iterator it;
+  unsigned int cnt;
+
+  if (!_checkTransactions())
+    return false;
+
+  if (!_assignCatsAndPayees())
+    return false;
+
+  if (!_adjustPCValues(_toDel, false))
+    return false;
+
+  if (!_adjustPCValues(_toAdd, true))
+    return false;
+
+  if ((_toAdd.size() || _toDel.size()) &&
+      !presentTransactionsToUser(_toAdd, _toDel))
+    return false;
+
+  /* add new transactions */
+  GWEN_WaitCallback_EnterWithText(GWEN_WAITCALLBACK_ID_FAST,
+				  _app->tr("Adding transactions to accounts").c_str(),
+				  _app->tr("transaction(s)").c_str(),
+				  0);
+  GWEN_WaitCallback_SetProgressTotal(_toAdd.size());
+  cnt=0;
+  GWEN_WaitCallback_SetProgressPos(cnt);
+  for (it=_toAdd.begin(); it!=_toAdd.end(); it++) {
+    Account *a;
+
+    a=_app->findAccount((*it).ref().getLocalBankCode().c_str(),
+			(*it).ref().getLocalAccountNumber().c_str());
+    assert(a);
+    a->addTransaction(*it);
+    cnt++;
+    GWEN_WaitCallbackProgress(cnt);
+  }
+  GWEN_WaitCallback_Leave();
+
+  /* del old transactions */
+  if (_toDel.size()) {
+    GWEN_WaitCallback_EnterWithText(GWEN_WAITCALLBACK_ID_FAST,
+				    _app->tr("Deleting transactions from accounts").c_str(),
+				    _app->tr("transaction(s)").c_str(),
+				    0);
+    GWEN_WaitCallback_SetProgressTotal(_toDel.size());
+    cnt=0;
+    GWEN_WaitCallback_SetProgressPos(cnt);
+    for (it=_toDel.begin(); it!=_toDel.end(); it++) {
+      Account *a;
+  
+      a=_app->findAccount((*it).ref().getLocalBankCode().c_str(),
+			  (*it).ref().getLocalAccountNumber().c_str());
+      assert(a);
+      a->removeTransaction((*it).ptr());
+      cnt++;
+      GWEN_WaitCallbackProgress(cnt);
+    }
+    GWEN_WaitCallback_Leave();
+  }
+
+  return true;
+
+}
+
+
+
+AB_ACCOUNT_STATUS*
+TransactionImporter::_getBestBalance(AB_IMEXPORTER_ACCOUNTINFO *ai,
+				     bool noted) {
+  AB_ACCOUNT_STATUS *ast;
+  AB_ACCOUNT_STATUS *best=0;
+
+  ast=AB_ImExporterAccountInfo_GetFirstAccountStatus(ai);
+  while(ast) {
+    if ((noted && AB_AccountStatus_GetNotedBalance(ast)) ||
+	(!noted && AB_AccountStatus_GetBookedBalance(ast))) {
+      if (!best)
+	best=ast;
+      else {
+	const GWEN_TIME *tiBest;
+	const GWEN_TIME *ti;
+
+	tiBest=AB_AccountStatus_GetTime(best);
+	ti=AB_AccountStatus_GetTime(ast);
+
+	if (!tiBest) {
+	  best=ast;
+	}
+	else {
+	  if (ti) {
+	    double d;
+
+	    /* we have two times, compare them */
+	    d=GWEN_Time_Diff(ti, tiBest);
+	    if (d>0)
+	      /* newer */
+	      best=ast;
+	  }
+	}
+      }
+    } /* if noted balance */
+    ast=AB_ImExporterAccountInfo_GetNextAccountStatus(ai);
+  } /* while */
+
+  return best;
+}
+
+
+
 bool TransactionImporter::importAccounts(){
   AB_IMEXPORTER_ACCOUNTINFO *ai;
 
   ai=AB_ImExporterContext_GetFirstAccountInfo(_context);
   while(ai) {
-    AB_ACCOUNT_STATUS *ast;
-    AB_ACCOUNT_STATUS *best;
     Account *a;
 
-    best=0;
     DBG_DEBUG(0, "Checking account (%s/%s)",
                AB_ImExporterAccountInfo_GetBankCode(ai),
                AB_ImExporterAccountInfo_GetAccountNumber(ai));
@@ -837,38 +955,27 @@ bool TransactionImporter::importAccounts(){
       /* account not found, TODO: ask the user to add it */
     }
     else {
-      ast=AB_ImExporterAccountInfo_GetFirstAccountStatus(ai);
-      while(ast) {
-        if (!best)
-          best=ast;
-        else {
-          const GWEN_TIME *tiBest;
-          const GWEN_TIME *ti;
-  
-          tiBest=AB_AccountStatus_GetTime(best);
-          ti=AB_AccountStatus_GetTime(ast);
-  
-          if (!tiBest) {
-            best=ast;
-          }
-          else {
-            if (ti) {
-              double d;
-  
-              /* we have two times, compare them */
-              d=GWEN_Time_Diff(ti, tiBest);
-              if (d>0)
-                /* newer */
-                best=ast;
-            }
-          }
-        }
-        ast=AB_ImExporterAccountInfo_GetNextAccountStatus(ai);
-      } /* while */
-    }
-    if (best) {
-      DBG_DEBUG(0, "Adding account status");
-      a->setAccountStatus(best);
+      AB_ACCOUNT_STATUS *bestBooked;
+      AB_ACCOUNT_STATUS *bestNoted;
+
+      /* get best booked balance */
+      bestBooked=_getBestBalance(ai, false);
+      bestNoted=_getBestBalance(ai, true);
+
+      if (bestBooked) {
+	if (AB_AccountStatus_GetNotedBalance(bestBooked)==0) {
+	  if (bestNoted) {
+	    const AB_BALANCE *bestNotedBalance;
+
+	    bestNotedBalance=AB_AccountStatus_GetNotedBalance(bestNoted);
+	    AB_AccountStatus_SetNotedBalance(bestBooked, bestNotedBalance);
+	  }
+	}
+	a->setAccountStatus(bestBooked);
+      }
+      else if (bestNoted) {
+	a->setAccountStatus(bestNoted);
+      }
     }
     ai=AB_ImExporterContext_GetNextAccountInfo(_context);
   } /* while accounts */
@@ -949,11 +1056,17 @@ bool TransactionImporter::importDatedTransfers(){
 
 bool TransactionImporter::importContext(){
   bool rv;
+  std::list<AccountData*>::iterator ait;
 
   rv=importTransactions();
   rv&=importAccounts();
   rv&=importStandingOrders();
   rv&=importDatedTransfers();
+
+  /* update views */
+  for (ait=_accountDataList.begin(); ait!=_accountDataList.end(); ait++) {
+    _app->appInfoTransactionsChanged((*ait)->account());
+  }
   return rv;
 }
 
