@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile: transaction.cpp,v $
                              -------------------
-    cvs         : $Id: transaction.cpp,v 1.24 2005/08/26 16:12:09 aquamaniac Exp $
+    cvs         : $Id: transaction.cpp,v 1.26 2006/01/28 11:13:57 aquamaniac Exp $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -37,7 +37,7 @@ Transaction::Transaction()
 ,_transactionCode(0)
 ,_textKey(51)
 ,_transactionId(0)
-,_modified(false){
+,_modified(false) {
 
 }
 
@@ -50,7 +50,7 @@ Transaction::Transaction(GWEN_DB_NODE *db)
 ,_transactionCode(0)
 ,_textKey(51)
 ,_transactionId(0)
-,_modified(false){
+,_modified(false) {
   if (!fromDb(db)) {
     DBG_ERROR(0, "Error loading transaction from DB");
     abort();
@@ -549,8 +549,7 @@ const GWEN_TIME *Transaction::getValutaDate() const{
 
 void Transaction::setValutaDate(const GWEN_TIME *d){
   GWEN_Time_free(_valutaDate);
-  if (d) _valutaDate=GWEN_Time_dup(d);
-  else _valutaDate=0;
+  _valutaDate=_transformedDate(d);
   _hash.erase();
   _modified=true;
 }
@@ -565,8 +564,7 @@ const GWEN_TIME *Transaction::getDate() const{
 
 void Transaction::setDate(const GWEN_TIME *d){
   GWEN_Time_free(_date);
-  if (d) _date=GWEN_Time_dup(d);
-  else _date=0;
+  _date=_transformedDate(d);
   _hash.erase();
   _modified=true;
 }
@@ -823,6 +821,31 @@ std::string Transaction::_makeHash() {
 }
 
 
+GWEN_TIME *Transaction::_transformedDate(const GWEN_TIME *ti) {
+  if (ti) {
+    GWEN_BUFFER *tbuf;
+    GWEN_TIME *tnew;
+    std::string s;
+
+    tbuf=GWEN_Buffer_new(0, 32, 0, 1);
+    if (GWEN_Time_toUtcString(ti, "YYYYMMDD", tbuf)) {
+      DBG_ERROR(0, "Could not store date");
+      GWEN_Buffer_free(tbuf);
+      return 0;
+    }
+
+    GWEN_Buffer_AppendString(tbuf, "-12:00");
+    tnew=GWEN_Time_fromUtcString(GWEN_Buffer_GetStart(tbuf),
+                                 "YYYYMMDD-hh:mm");
+    assert(tnew);
+    GWEN_Buffer_free(tbuf);
+    return tnew;
+  }
+
+  return 0;
+}
+
+
 
 bool Transaction::toDb(GWEN_DB_NODE *db) const {
   std::list<std::string>::const_iterator it;
@@ -1349,6 +1372,97 @@ void Transaction::gatherInfoFromPurpose() {
 }
 
 
+std::string Transaction::getHashData() {
+  std::string s;
+  std::list<std::string>::iterator it;
+  char buffer[32];
+  GWEN_BUFFER *dbuf;
+
+  s=_localCountry;
+  s+="#";
+  s+=_localBankCode;
+  s+="#";
+  s+=_localAccountNumber;
+  s+="#";
+  s+=_localSuffix;
+  s+="#";
+  s+=_localOwnerName;
+  s+="#";
+  s+=_remoteCountry;
+  s+="#";
+  s+=_remoteBankCode;
+  s+="#";
+  s+=_remoteAccountNumber;
+  s+="#";
+  s+=_remoteSuffix;
+  s+="#";
+  for (it=_remoteName.begin(); it!=_remoteName.end(); it++){
+    s+=*it;
+    s+=" ";
+  }
+  s+="#";
+
+  snprintf(buffer, sizeof(buffer), "%i", _textKey);
+  s+=buffer;
+  s+="#";
+
+  if (_valutaDate) {
+    snprintf(buffer, sizeof(buffer), GWEN_TYPE_TMPL_UINT32,
+	     (unsigned int)GWEN_Time_Seconds(_valutaDate));
+    s+=buffer;
+  }
+  s+="#";
+  if (_date) {
+    snprintf(buffer, sizeof(buffer), GWEN_TYPE_TMPL_UINT32,
+	     (unsigned int)GWEN_Time_Seconds(_date));
+    s+=buffer;
+  }
+  s+="#";
+  if (_value) {
+    if (AB_Value_IsValid(_value)) {
+      const char *p;
+
+      snprintf(buffer, sizeof(buffer), "%lf",
+	       AB_Value_GetValue(_value));
+      s+=buffer;
+      s+=" ";
+      p=AB_Value_GetCurrency(_value);
+      if (p)
+        s+=p;
+    }
+  }
+  s+="#";
+  s+=_transactionKey;
+  s+="#";
+  s+=_customerReference;
+  s+="#";
+  s+=_bankReference;
+  s+="#";
+  snprintf(buffer, sizeof(buffer), "%d", _transactionCode);
+  s+=buffer;
+  s+="#";
+  s+=_transactionText;
+  s+="#";
+  s+=_primanota;
+  s+="#";
+  s+=_fiid;
+  s+="#";
+  for (it=_purpose.begin(); it!=_purpose.end(); it++){
+    s+=*it;
+    s+=" ";
+  }
+
+  /* s now contains all important data */
+  dbuf=GWEN_Buffer_new(0, s.length(), 0, 1);
+  GWEN_Buffer_AppendString(dbuf, s.c_str());
+  /* remove duplicate blanks */
+  GWEN_Text_CondenseBuffer(dbuf);
+
+  s=std::string(GWEN_Buffer_GetStart(dbuf));
+  GWEN_Buffer_free(dbuf);
+
+  return s;
+}
 
 
 
