@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile: xastorage.c,v $
                              -------------------
-    cvs         : $Id: xastorage.c,v 1.8 2005/03/28 08:48:41 aquamaniac Exp $
+    cvs         : $Id: xastorage.c,v 1.9 2006/03/08 15:38:34 aquamaniac Exp $
     begin       : Mon Apr 05 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -23,6 +23,7 @@
 #include <stdlib.h>
 #include <assert.h>
 #include <string.h>
+#include <unistd.h>
 
 #ifdef WIN32
 # define snprintf _snprintf
@@ -298,12 +299,17 @@ int AH_Storage_SaveDay(AH_STORAGE *st, AH_STORAGE_DAY *dy) {
     return -1;
   }
 
-  if (GWEN_DB_WriteFile(AH_Storage_Day_GetTransactions(dy),
-                        AH_Storage_Day_GetFileName(dy),
-                        GWEN_DB_FLAGS_DEFAULT)) {
-    DBG_ERROR(0, "Could not save day \"%s\"",
-              AH_Storage_Day_GetFileName(dy));
-    return -1;
+  if (GWEN_DB_Groups_Count(AH_Storage_Day_GetTransactions(dy))) {
+    if (GWEN_DB_WriteFile(AH_Storage_Day_GetTransactions(dy),
+                          AH_Storage_Day_GetFileName(dy),
+                          GWEN_DB_FLAGS_DEFAULT)) {
+      DBG_ERROR(0, "Could not save day \"%s\"",
+                AH_Storage_Day_GetFileName(dy));
+      return -1;
+    }
+  }
+  else {
+    unlink(AH_Storage_Day_GetFileName(dy));
   }
 
   return 0;
