@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile: categoryreport.cpp,v $
                              -------------------
-    cvs         : $Id: categoryreport.cpp,v 1.1 2005/09/01 07:27:38 aquamaniac Exp $
+    cvs         : $Id: categoryreport.cpp,v 1.4 2006/02/09 14:11:06 aquamaniac Exp $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -50,7 +50,6 @@
 
 #include <qwidget.h>
 #include <qstring.h>
-#include <qmessagebox.h>
 #include <qwidget.h>
 
 #define I18N_NOOP(msg) msg
@@ -88,7 +87,7 @@ QString CategoryReport::longDescription(){
 
 
 bool CategoryReport::initProfile(GWEN_DB_NODE *dbProfile, QWidget *parent){
-  EditCategoryReport w(dbProfile, parent);
+  EditCategoryReport w(app(), dbProfile, parent);
 
   w.setCaption(QWidget::tr("Create new profile"));
   if (w.exec()!=QDialog::Accepted)
@@ -100,7 +99,7 @@ bool CategoryReport::initProfile(GWEN_DB_NODE *dbProfile, QWidget *parent){
 
 
 bool CategoryReport::editProfile(GWEN_DB_NODE *dbProfile, QWidget *parent){
-  EditCategoryReport w(dbProfile, parent);
+  EditCategoryReport w(app(), dbProfile, parent);
 
   w.setCaption(QWidget::tr("Edit profile"));
   if (w.exec()!=QDialog::Accepted)
@@ -412,14 +411,11 @@ QString CategoryReport::handleCategory(GWEN_DB_NODE *dbProfile,
 
   cat=cd->getCategory();
 
-  sortYears(cd->years());
-
   for (yit=cd->years().begin();
        yit!=cd->years().end();
        yit++) {
     std::list<Month*>::iterator mit;
 
-    sortMonths((*yit)->months());
     for (mit=(*yit)->months().begin();
          mit!=(*yit)->months().end();
          mit++) {
@@ -477,6 +473,9 @@ QString CategoryReport::_handleRealCategory(GWEN_DB_NODE *dbProfile,
     }
     AB_Value_AddValue(catVal, cd->getValue());
   }
+  else {
+    DBG_ERROR(0, "Category \"%s\" not found", cat->getId().c_str());
+  }
 
   for (it=cat->getChildren().begin();
        it!=cat->getChildren().end();
@@ -585,6 +584,9 @@ bool CategoryReport::useProfile(GWEN_DB_NODE *dbProfile, QWidget *parent){
     addTransaction(cdl, *it);
   } // for
 
+  for (cit=cdl.begin(); cit!=cdl.end(); cit++)
+    (*cit)->sort();
+
   app()->sortCategories();
 
   DBG_ERROR(0, "Printing report...");
@@ -642,6 +644,7 @@ bool CategoryReport::useProfile(GWEN_DB_NODE *dbProfile, QWidget *parent){
     qs+=QWidget::tr("Amount");
     qs+="</b></th></tr>\n";
   }
+
   for (clit=app()->getCategories().begin();
        clit!=app()->getCategories().end();
        clit++) {
