@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile: editcategoryreport.h,v $
                              -------------------
-    cvs         : $Id: editcategoryreport.h,v 1.1 2005/09/01 07:27:38 aquamaniac Exp $
+    cvs         : $Id: editcategoryreport.h,v 1.2 2006/01/24 01:01:48 aquamaniac Exp $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -21,6 +21,8 @@
 
 
 class QComboBox;
+class KBanking;
+
 
 class EditCategoryReport:public EditCategoryReportUi {
   Q_OBJECT
@@ -32,7 +34,8 @@ private:
   void _guiToProfile(GWEN_DB_NODE *dbProfile);
 
 public:
-  EditCategoryReport(GWEN_DB_NODE *dbProfile,
+  EditCategoryReport(KBanking *kb,
+                     GWEN_DB_NODE *dbProfile,
                      QWidget* parent=0,
                      const char* name=0,
                      bool modal=FALSE,
