@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile: editsimplereport.h,v $
                              -------------------
-    cvs         : $Id: editsimplereport.h,v 1.2 2005/02/21 15:14:19 cstim Exp $
+    cvs         : $Id: editsimplereport.h,v 1.3 2006/01/24 01:01:48 aquamaniac Exp $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -20,6 +20,7 @@
 #include <gwenhywfar/db.h>
 
 
+class KBanking;
 class QComboBox;
 
 class EditSimpleReport:public EditSimpleReportUi {
@@ -32,7 +33,8 @@ private:
   void _guiToProfile(GWEN_DB_NODE *dbProfile);
 
 public:
-  EditSimpleReport(GWEN_DB_NODE *dbProfile,
+  EditSimpleReport(KBanking *kb,
+                   GWEN_DB_NODE *dbProfile,
                    QWidget* parent=0,
                    const char* name=0,
                    bool modal=FALSE,
