@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile: editsummaryreport.h,v $
                              -------------------
-    cvs         : $Id: editsummaryreport.h,v 1.1 2005/08/19 18:21:54 aquamaniac Exp $
+    cvs         : $Id: editsummaryreport.h,v 1.2 2006/01/24 01:01:48 aquamaniac Exp $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -21,6 +21,8 @@
 
 
 class QComboBox;
+class KBanking;
+
 
 class EditSummaryReport:public EditSummaryReportUi {
   Q_OBJECT
@@ -31,7 +33,8 @@ private:
   void _guiToProfile(GWEN_DB_NODE *dbProfile);
 
 public:
-  EditSummaryReport(GWEN_DB_NODE *dbProfile,
+  EditSummaryReport(KBanking *kb,
+                    GWEN_DB_NODE *dbProfile,
                     QWidget* parent=0,
                     const char* name=0,
                     bool modal=FALSE,
