@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile: accountview.h,v $
                              -------------------
-    cvs         : $Id: accountview.h,v 1.7 2005/08/24 16:52:02 aquamaniac Exp $
+    cvs         : $Id: accountview.h,v 1.8 2006/01/11 13:15:50 aquamaniac Exp $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -43,11 +43,14 @@ private:
   KBanking *_app;
   AccountListView *_accList;
 
-  protected slots:
-    void slotUpdated();
-    void slotDetails();
-    void slotTransactions();
-    void slotUpdate();
+  void _accountUpdate(bool forceTimeSpan);
+
+protected slots:
+  void slotUpdated();
+  void slotDetails();
+  void slotTransactions();
+  void slotUpdate();
+  void slotUpdateWithTimeSpan();
 
 };
 
