@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile: datedxferview.cpp,v $
                              -------------------
-    cvs         : $Id: datedxferview.cpp,v 1.2 2005/07/13 13:47:35 aquamaniac Exp $
+    cvs         : $Id: datedxferview.cpp,v 1.5 2005/11/25 16:49:41 cstim Exp $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -52,20 +52,20 @@ DatedTransferView::DatedTransferView(KBanking *app,
   QBoxLayout *transferBoxLayout = new QHBoxLayout( transferBox->layout() );
   transferBoxLayout->setAlignment( Qt::AlignTop );
 
-  _xaList=new TransferListView((QWidget*)transferBox, name);
+  _xaList=new TransferListView(transferBox, name);
   transferBoxLayout->addWidget(_xaList);
 
-  QObject::connect((QObject*)app->flagStaff(),
+  QObject::connect(app->flagStaff(),
                    SIGNAL(signalDatedTransfersUpdated()),
                    this, SLOT(slotUpdated()));
 
-  QObject::connect((QObject*)detailsButton, SIGNAL(clicked()),
+  QObject::connect(detailsButton, SIGNAL(clicked()),
                    this, SLOT(slotDetails()));
-  QObject::connect((QObject*)newDatedTransferButton, SIGNAL(clicked()),
+  QObject::connect(newDatedTransferButton, SIGNAL(clicked()),
                    this, SLOT(slotNewDatedTransfer()));
-  QObject::connect((QObject*)modifyDatedTransferButton, SIGNAL(clicked()),
+  QObject::connect(modifyDatedTransferButton, SIGNAL(clicked()),
                    this, SLOT(slotModifyDatedTransfer()));
-  QObject::connect((QObject*)deleteDatedTransferButton, SIGNAL(clicked()),
+  QObject::connect(deleteDatedTransferButton, SIGNAL(clicked()),
                    this, SLOT(slotDeleteDatedTransfer()));
 }
 
@@ -253,12 +253,12 @@ AB_JOB *DatedTransferView::_newDatedXferJob(AB_JOB_TYPE jt,
     ba=_app->getAccount(acc->getBankingId());
     if (!ba) {
       DBG_ERROR(0, "Account not available");
-      QMessageBox::critical(0,
+      QMessageBox::critical(this,
                             tr("Account Not Available"),
                             tr("The account you requested is not "
                                "available\n"
                                "with any backend."),
-                            tr("Dismiss"), 0, 0, 0);
+                            tr("Dismiss"), QString::null);
       return 0;
     }
 
@@ -279,12 +279,12 @@ AB_JOB *DatedTransferView::_newDatedXferJob(AB_JOB_TYPE jt,
     rv=AB_Job_CheckAvailability(job);
     if (rv) {
       DBG_NOTICE(0, "Job is not available (%d)", rv);
-      QMessageBox::critical(0,
+      QMessageBox::critical(this,
                             tr("Job Not Available"),
                             tr("The job you requested is not "
                                "available with\n"
                                "the backend which handles this account.\n"),
-                            tr("Dismiss"), 0, 0, 0);
+                            tr("Dismiss"), QString::null);
       AB_Job_free(job);
       return 0;
     }
@@ -297,7 +297,7 @@ AB_JOB *DatedTransferView::_newDatedXferJob(AB_JOB_TYPE jt,
     switch(res) {
     case AB_BankInfoCheckResult_NotOk:
       DBG_INFO(0, "Account check result: %d", res);
-      i=QMessageBox::warning(0,
+      i=QMessageBox::warning(this,
                              tr("Warning"),
                              tr("<qt>"
                                 "<p>"
@@ -307,10 +307,10 @@ AB_JOB *DatedTransferView::_newDatedXferJob(AB_JOB_TYPE jt,
                                 "Do you want to review the order?"
                                 "<qt>"
                                ),
-                             tr("Yes"), tr("No"), tr("Abort"));
-      if (i==0)
+                             QMessageBox::Yes,QMessageBox::No,QMessageBox::Abort);
+      if (i==0 || i == QMessageBox::Yes)
         bad=true;
-      else if (i!=1) {
+      else if (i!=1 && i != QMessageBox::No) {
         AB_Job_free(job);
         return 0;
       }
@@ -318,7 +318,7 @@ AB_JOB *DatedTransferView::_newDatedXferJob(AB_JOB_TYPE jt,
 
     case AB_BankInfoCheckResult_UnknownBank:
       DBG_INFO(0, "Account check result: %d", res);
-      i=QMessageBox::warning(0,
+      i=QMessageBox::warning(this,
                              tr("Warning"),
                              tr("<qt>"
                                 "<p>"
@@ -327,10 +327,10 @@ AB_JOB *DatedTransferView::_newDatedXferJob(AB_JOB_TYPE jt,
                                 "Do you want to review the order?"
                                 "<qt>"
                                ),
-                             tr("Yes"), tr("No"), tr("Abort"));
-      if (i==0)
+                             QMessageBox::Yes,QMessageBox::No,QMessageBox::Abort);
+      if (i==0 || i == QMessageBox::Yes)
         bad=true;
-      else if (i!=1) {
+      else if (i!=1 && i != QMessageBox::No) {
         AB_Job_free(job);
         return 0;
       }
@@ -369,7 +369,7 @@ AB_JOB *DatedTransferView::_newDatedXferJob(AB_JOB_TYPE jt,
 
       if (rv) {
         DBG_NOTICE(0, "Could not set transfer (%d)", rv);
-        if (QMessageBox::critical(0,
+        int res = QMessageBox::critical(this,
                                   tr("Bad Transfer Data"),
                                   tr("<qt>"
                                      "<p>"
@@ -381,7 +381,8 @@ AB_JOB *DatedTransferView::_newDatedXferJob(AB_JOB_TYPE jt,
                                      "</p>"
                                      "<qt>"
                                     ),
-                                  tr("Yes"), tr("Abort"), 0, 0)!=0){
+                                  QMessageBox::Yes,QMessageBox::Abort);
+	if (res !=0 && res != QMessageBox::Yes){
           AB_Transaction_free(abt);
           AB_Job_free(job);
           return 0;
@@ -419,7 +420,7 @@ void DatedTransferView::_createDatedTransfer(RefPointer<Transfer> tmpl){
     }
     AB_Job_free(job);
 
-    QMessageBox::information(0,
+    QMessageBox::information(this,
                              tr("Job enqueued"),
                              tr("<qt>"
                                 "A dated transfer creation job has been "
@@ -429,7 +430,7 @@ void DatedTransferView::_createDatedTransfer(RefPointer<Transfer> tmpl){
                                 "actually send\n"
                                 "the enqueued jobs."
                                 "</qt>"),
-                             tr("Dismiss"), 0, 0, 0);
+                             tr("Dismiss"), QString::null);
   }
 }
 
@@ -451,7 +452,7 @@ void DatedTransferView::_modifyDatedTransfer(RefPointer<Transfer> tmpl){
     }
     AB_Job_free(job);
 
-    QMessageBox::information(0,
+    QMessageBox::information(this,
                              tr("Job enqueued"),
                              tr("<qt>"
                                 "A dated transfer modification job has been "
@@ -461,7 +462,7 @@ void DatedTransferView::_modifyDatedTransfer(RefPointer<Transfer> tmpl){
                                 "actually send\n"
                                 "the enqueued jobs."
                                 "</qt>"),
-                             tr("Dismiss"), 0, 0, 0);
+                             tr("Dismiss"), QString::null);
   }
 }
 
@@ -479,13 +480,13 @@ void DatedTransferView::slotModifyDatedTransfer() {
   t=_xaList->getCurrentTransfer();
   if (!t.isValid()) {
     DBG_ERROR(0, "No current dated transfer");
-    QMessageBox::critical(0,
+    QMessageBox::critical(this,
                           tr("No Selection"),
                           tr("<qt>"
                              "Please select a dated transfer for "
                              "modification"
                              "</qt>"),
-                          tr("Dismiss"), 0, 0, 0, 0);
+                          tr("Dismiss"), QString::null, QString::null, 0, 0);
     return;
   }
 
@@ -506,13 +507,13 @@ void DatedTransferView::slotDeleteDatedTransfer() {
   t=_xaList->getCurrentTransfer();
   if (!t.isValid()) {
     DBG_ERROR(0, "No current dated transfer");
-    QMessageBox::critical(0,
+    QMessageBox::critical(this,
                           tr("No Selection"),
                           tr("<qt>"
                              "Please select a dated transfer for "
                              "modification"
                              "</qt>"),
-                          tr("Dismiss"), 0, 0, 0, 0);
+                          tr("Dismiss"), QString::null, QString::null, 0, 0);
     return;
   }
 
@@ -523,13 +524,13 @@ void DatedTransferView::slotDeleteDatedTransfer() {
                                           accountNumber);
   if (!ba) {
     DBG_ERROR(0, "Account for dated transfer not found");
-    QMessageBox::critical(0,
+    QMessageBox::critical(this,
                           tr("Unknown Account"),
                           tr("<qt>"
                              "This dated transfer does not belong "
                              "to any known account."
                              "</qt>"),
-                          tr("Dismiss"), 0, 0, 0, 0);
+                          tr("Dismiss"), QString::null, QString::null, 0, 0);
     return;
   }
 
@@ -537,13 +538,13 @@ void DatedTransferView::slotDeleteDatedTransfer() {
   rv=AB_Job_CheckAvailability(job);
   if (rv) {
     DBG_ERROR(0, "Job is not available (%d)", rv);
-    QMessageBox::critical(0,
+    QMessageBox::critical(this,
                           tr("Job Not Available"),
                           tr("<qt>"
                              "The selected job is not available with "
                              "your bank and this account."
                              "</qt>"),
-                          tr("Dismiss"), 0, 0, 0, 0);
+                          tr("Dismiss"), QString::null, QString::null, 0, 0);
     AB_Job_free(job);
     return;
   }
@@ -554,14 +555,14 @@ void DatedTransferView::slotDeleteDatedTransfer() {
   rv=AB_JobDeleteDatedTransfer_SetTransaction(job, abt);
   if (rv) {
     DBG_ERROR(0, "Error on SetTransaction: %d", rv);
-    QMessageBox::critical(0,
+    QMessageBox::critical(this,
                           tr("Internal Error"),
                           tr("<qt>"
                              "An internal error occurred. "
                              "Please check console logs and report to "
                              "<b>martin@libchipcard.de</b>"
                              "</qt>"),
-                          tr("Dismiss"), 0, 0, 0, 0);
+                          tr("Dismiss"), QString::null, QString::null, 0, 0);
     AB_Job_free(job);
     return;
   }
@@ -570,20 +571,20 @@ void DatedTransferView::slotDeleteDatedTransfer() {
   AB_Job_free(job);
   if (rv) {
     DBG_NOTICE(0, "Error enqueing job: %d", rv);
-    QMessageBox::critical(0,
+    QMessageBox::critical(this,
                           tr("Job Not Enqueued"),
                           tr("<qt>"
                              "The selected job is available with "
                              "your bank and this account but an error "
                              "occurred while enqueuing it."
                              "</qt>"),
-                          tr("Dismiss"), 0, 0, 0, 0);
+                          tr("Dismiss"), QString::null, QString::null, 0, 0);
     return;
   }
 
   slotUpdated();
 
-  QMessageBox::information(0,
+  QMessageBox::information(this,
                            tr("Job enqueued"),
                            tr("<qt>"
                               "A job to delete a dated transfer has been "
@@ -593,7 +594,7 @@ void DatedTransferView::slotDeleteDatedTransfer() {
                               "actually send\n"
                               "the enqueued jobs."
                               "</qt>"),
-                           tr("Dismiss"), 0, 0, 0);
+                           tr("Dismiss"), QString::null);
 
 }
 
