@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile: transferview.h,v $
                              -------------------
-    cvs         : $Id: transferview.h,v 1.8 2005/08/24 16:52:02 aquamaniac Exp $
+    cvs         : $Id: transferview.h,v 1.10 2005/09/07 15:38:38 aquamaniac Exp $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -46,12 +46,6 @@ private:
   KBanking *_app;
   TransferListView *_xaList;
 
-  AB_JOB *_newTransferJob(Transfer::TransferType tt,
-                          RefPointer<Transfer> tmpl=0);
-  void _newTransfer(RefPointer<Transfer> tmpl=0);
-  void _newDebitNote(RefPointer<Transfer> tmpl=0);
-  void _newEuTransfer(RefPointer<Transfer> tmpl=0);
-
 public slots:
   void slotUpdated();
   void slotDetails();
@@ -59,6 +53,7 @@ public slots:
   void slotNewDebitNote();
   void slotNewEuTransfer();
   void slotRepeat();
+
 };
 
 
