@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile: transactionlist.cpp,v $
                              -------------------
-    cvs         : $Id: transactionlist.cpp,v 1.17 2005/08/31 06:09:39 aquamaniac Exp $
+    cvs         : $Id: transactionlist.cpp,v 1.23 2006/01/11 13:15:50 aquamaniac Exp $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -38,6 +38,7 @@
 TransactionListViewItem::TransactionListViewItem(TransactionListView *parent,
                                                  RefPointer<Transaction> t)
 :QListViewItem(parent)
+,_isNew(false)
 ,_needUpdate(false)
 ,_transaction(t){
   TransactionListView *lv;
@@ -58,6 +59,7 @@ TransactionListViewItem::TransactionListViewItem(TransactionListView *parent,
 
 TransactionListViewItem::TransactionListViewItem(const TransactionListViewItem &item)
 :QListViewItem(item)
+,_isNew(false)
 ,_needUpdate(false) {
   int i;
 
@@ -73,6 +75,7 @@ TransactionListViewItem::TransactionListViewItem(TransactionListView *parent,
                                                  QListViewItem *after,
                                                  RefPointer<Transaction> t)
 :QListViewItem(parent, after)
+,_isNew(false)
 ,_needUpdate(false)
 ,_transaction(t){
   TransactionListView *lv;
@@ -150,6 +153,7 @@ void TransactionListViewItem::_populate(bool isCurrent) {
   QString pname;
   QString cname;
   TransactionListView *tv;
+  GWEN_TYPE_UINT32 sess;
 
   tv=dynamic_cast<TransactionListView*>(listView());
   assert(tv);
@@ -161,6 +165,16 @@ void TransactionListViewItem::_populate(bool isCurrent) {
     _cell[i]=0;
   }
 
+  /* prepare colour */
+  sess=tv->getLastSessionId();
+  if (sess) {
+    // only modify _isNew if there is a session id
+    if (_transaction.ref().getTransactionId()>=sess)
+      _isNew=true;
+    else
+      _isNew=false;
+  }
+
   i=0;
   ht=0;
 
@@ -302,7 +316,7 @@ void TransactionListViewItem::_populate(bool isCurrent) {
         cat=app->findCategoryById(cid.c_str());
         if (cat) {
           if (cat->isIncome())
-            cname="<font color=green>";
+            cname="<font color=\"dark green\">";
           else
             cname="<font color=red>";
           cname+=QString::fromUtf8(cat->getName().c_str());
@@ -373,8 +387,7 @@ QString TransactionListViewItem::key(int column, bool ascending) const{
       result=QString(numbuf);
       s=AB_Value_GetCurrency(v);
       if (s) {
-        result+=" ";
-        result+=AB_Value_GetCurrency(v);
+	result+= " " + QString::fromUtf8(AB_Value_GetCurrency(v));
       }
     }
     else
@@ -426,11 +439,17 @@ void TransactionListViewItem::paintCell(QPainter * pnt,
       br=QBrush(QColor(_colour.c_str()));
     }
     else {
-      if (column & 1)
-        br=QBrush(QColor("light yellow"));
+      if (_isNew) {
+        br=QBrush(QColor("yellow"));
+      }
+      else {
+        if (itemPos() & 1)
+          //if (column & 1)
+          br=QBrush(QColor("light yellow"));
         //br=cg.brush(QColorGroup::Light);
-      else
-        br=cg.brush(QColorGroup::Midlight);
+        else
+          br=cg.brush(QColorGroup::Midlight);
+      }
     }
   }
 
@@ -482,6 +501,7 @@ TransactionListView::TransactionListView(KBanking *app,
 ,_shortList(shortList)
 ,_app(app)
 ,_needUpdate(false)
+,_lastSessionId(0)
 ,_modify(0) {
   setAllColumnsShowFocus(true);
   setShowSortIndicator(true);
@@ -495,7 +515,7 @@ TransactionListView::TransactionListView(KBanking *app,
   addColumn(QWidget::tr("Payee/Category"),-1);
   setColumnAlignment(5, Qt::AlignRight);
   header()->setTracking(false);
-  QObject::connect((QObject*)header(), SIGNAL(sizeChange(int, int, int)),
+  QObject::connect(header(), SIGNAL(sizeChange(int, int, int)),
                    this, SLOT(slotHeaderChanged(int, int, int)));
 
 }
@@ -509,6 +529,7 @@ TransactionListView::TransactionListView(bool shortList,
 ,_shortList(shortList)
 ,_app(0)
 ,_needUpdate(false)
+,_lastSessionId(0)
 ,_modify(0) {
   setAllColumnsShowFocus(true);
   setShowSortIndicator(true);
@@ -522,7 +543,7 @@ TransactionListView::TransactionListView(bool shortList,
   addColumn(QWidget::tr("Payee"),-1);
   setColumnAlignment(5, Qt::AlignRight);
   header()->setTracking(false);
-  QObject::connect((QObject*)header(), SIGNAL(sizeChange(int, int, int)),
+  QObject::connect(header(), SIGNAL(sizeChange(int, int, int)),
                    this, SLOT(slotHeaderChanged(int, int, int)));
 
 }
@@ -547,7 +568,7 @@ TransactionListView::TransactionListView(QWidget *parent, const char *name)
   addColumn(QWidget::tr("Payee"),-1);
   setColumnAlignment(5, Qt::AlignRight);
   header()->setTracking(false);
-  QObject::connect((QObject*)header(), SIGNAL(sizeChange(int, int, int)),
+  QObject::connect(header(), SIGNAL(sizeChange(int, int, int)),
                    this, SLOT(slotHeaderChanged(int, int, int)));
 
 }
@@ -591,7 +612,7 @@ void TransactionListView::addTransactions(const std::list<RefPointer<Transaction
     pd=new QProgressDialog(tr("Populating transaction list, please wait..."),
                            tr("Abort"),
                            ts.size(),
-                           0, // parent
+                           this, // parent
                            "ProgressDialog",
                            true);
     pd->setCaption(tr("Working..."));
@@ -674,6 +695,18 @@ void TransactionListView::slotHeaderChanged(int section,
 
 
 
+void TransactionListView::setLastSessionId(GWEN_TYPE_UINT32 sess) {
+  _lastSessionId=sess;
+}
+
+
+
+GWEN_TYPE_UINT32 TransactionListView::getLastSessionId() const {
+  return _lastSessionId;
+}
+
+
+
 void TransactionListView::updateAll() {
   TransactionListViewItem *entry;
 
